AIFunctionDeclaration class abstract

Represents a function that can be described to an AI service.

AIFunctionDeclaration is the base class for AIFunction, which adds the ability to invoke the function. Components can type-test an AITool for AIFunctionDeclaration to determine whether it can be described as a function, and for AIFunction to determine whether it can be invoked.

Inheritance
Implementers
Annotations
  • @Source(name: 'AIFunctionDeclaration.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Functions/')

Constructors

AIFunctionDeclaration({required String? name, String? description, Map<String, dynamic>? parametersSchema, Map<String, dynamic>? returnSchema})
Creates a new AIFunctionDeclaration.

Properties

additionalProperties AdditionalPropertiesDictionary?
Additional properties.
getter/setter pairinherited
description String?
A description of the tool.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the tool.
finalinherited
parametersSchema Map<String, dynamic>?
The JSON schema describing the function's input parameters.
final
returnSchema Map<String, dynamic>?
The JSON schema describing the function's return value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getService<T>({Object? key}) → T?
Gets a service of the specified type.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited