AnonymousDelegatingChatClient class
A DelegatingChatClient that uses anonymous delegates to implement its functionality.
This makes it easy to create custom middleware without subclassing DelegatingChatClient.
- Inheritance
-
- Object
- DelegatingChatClient
- AnonymousDelegatingChatClient
- Available extensions
- Annotations
-
- @Source(name: 'AnonymousDelegatingChatClient.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI/ChatCompletion/', commit: 'b56aec451afe841d1865da4c9cb45fd5a379a519')
Constructors
- AnonymousDelegatingChatClient(ChatClient innerClient, {ChatClientResponseHandler? responseHandler, ChatClientStreamingResponseHandler? streamingResponseHandler})
- Creates a new AnonymousDelegatingChatClient.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- innerClient → ChatClient
-
The inner client to delegate to.
finalinherited
- responseHandler → ChatClientResponseHandler?
-
The handler for non-streaming responses.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamingResponseHandler → ChatClientStreamingResponseHandler?
-
The handler for streaming responses.
final
Methods
-
dispose(
) → void -
Performs application-defined tasks associated with freeing, releasing,
or resetting unmanaged resources.
inherited
-
getChatResponseFromMessage(
ChatMessage message, {ChatOptions? options, CancellationToken? cancellationToken}) → Future< ChatResponse> -
Available on ChatClient, provided by the ChatClientExtensions extension
Sends a single message and returns the response. -
getChatResponseFromText(
String message, {ChatOptions? options, CancellationToken? cancellationToken}) → Future< ChatResponse> -
Available on ChatClient, provided by the ChatClientExtensions extension
Sends a single user text message and returns the response. -
getResponse(
{required Iterable< ChatMessage> messages, ChatOptions? options, CancellationToken? cancellationToken}) → Future<ChatResponse> -
Sends a chat request and returns the complete response.
override
-
getService<
T> ({Object? key}) → T? -
Gets a service of the specified type.
inherited
-
getStreamingChatResponseFromMessage(
ChatMessage message, {ChatOptions? options, CancellationToken? cancellationToken}) → Stream< ChatResponseUpdate> -
Available on ChatClient, provided by the ChatClientExtensions extension
Sends a single message and returns a streaming response. -
getStreamingChatResponseFromText(
String message, {ChatOptions? options, CancellationToken? cancellationToken}) → Stream< ChatResponseUpdate> -
Available on ChatClient, provided by the ChatClientExtensions extension
Sends a single user text message and returns a streaming response. -
getStreamingResponse(
{required Iterable< ChatMessage> messages, ChatOptions? options, CancellationToken? cancellationToken}) → Stream<ChatResponseUpdate> -
Sends a chat request and returns a stream of response updates.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited