ChatConfiguration class

Specifies the ChatClient to use when evaluation is performed by an AI model.

Annotations
  • @Source(name: 'ChatConfiguration.cs', namespace: 'Microsoft.Extensions.AI.Evaluation', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation/')

Constructors

ChatConfiguration(ChatClient chatClient)
Creates a ChatConfiguration wrapping chatClient.
const

Properties

chatClient ChatClient
The ChatClient used to communicate with an AI model during evaluation.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited