ChatFinishReason class
Represents the reason a chat response finished being generated.
- Annotations
-
- @Source(name: 'ChatFinishReason.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/ChatCompletion/', commit: 'c378af04f386f8c6b1980c47822b1ca0ac7bf639')
Constructors
- ChatFinishReason(String value)
-
Creates a new ChatFinishReason with the given
value.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- contentFilter → const ChatFinishReason
- The response was filtered by a content filter.
- length → const ChatFinishReason
- The model reached the maximum output token limit.
- stop → const ChatFinishReason
- The model finished generating naturally (e.g. end of turn).
- toolCalls → const ChatFinishReason
- The model is requesting tool calls to be made.