allowBackgroundResponses property
Whether non-streaming responses may start a background operation and return a continuation token for polling.
Implementation
bool? allowBackgroundResponses;
Whether non-streaming responses may start a background operation and return a continuation token for polling.
bool? allowBackgroundResponses;