ChatToolMode class

Represents the mode in which tools are used by the chat client.

Implementers

Constructors

ChatToolMode()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

requireSpecific(String functionName) RequiredChatToolMode
The model must call the specified function.

Constants

auto → const AutoChatToolMode
Tools may optionally be used by the model.
none → const NoneChatToolMode
No tools should be used by the model.
requireAny → const RequiredChatToolMode
The model must call at least one tool (any tool).