CodeInterpreterToolResultContent class
Represents the result of a code interpreter tool invocation by a hosted service.
Outputs can include DataContent for binary data, text output, or HostedFileContent for generated files.
- Inheritance
-
- Object
- AIContent
- ToolResultContent
- CodeInterpreterToolResultContent
- Annotations
-
- @Source(name: 'CodeInterpreterToolResultContent.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Contents/')
Constructors
-
CodeInterpreterToolResultContent({required String callId, List<
AIContent> ? outputs, Object? rawRepresentation, AdditionalPropertiesDictionary? additionalProperties}) - Creates a new CodeInterpreterToolResultContent.
Properties
- additionalProperties ↔ AdditionalPropertiesDictionary?
-
Additional properties.
getter/setter pairinherited
- callId → String
-
The ID of the ToolCallContent this result corresponds to.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
outputs
↔ List<
AIContent> ? -
The output contents produced by the code interpreter tool.
getter/setter pair
- rawRepresentation ↔ Object?
-
The underlying implementation-specific representation of this content.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited