ContentSafetyServiceConfiguration class
Configuration for connecting to the Azure AI Foundry Evaluation service.
Supports both Hub-based projects (subscription + resource group + project name) and non-Hub-based Foundry projects (endpoint URI only).
- Annotations
-
- @Source(name: 'ContentSafetyServiceConfiguration.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.Safety', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.Safety/')
Constructors
- ContentSafetyServiceConfiguration.foundry({required Uri endpoint, required String apiKey, int timeoutInSeconds = 120})
-
Creates a configuration for a non-Hub-based Foundry project.
const
- ContentSafetyServiceConfiguration.hubBased({required String? subscriptionId, required String? resourceGroupName, required String? projectName, required String apiKey, Uri? endpoint, int timeoutInSeconds = 120})
-
Creates a configuration for a Hub-based Azure AI Foundry project.
const
Properties
- apiKey → String
-
API key for authentication.
final
- endpoint → Uri?
-
Endpoint URI for non-Hub-based Foundry projects.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isHubBasedProject → bool
-
Whether this is a Hub-based project configuration.
no setter
- projectName → String?
-
Azure AI Foundry project name (Hub-based projects only).
final
- resourceGroupName → String?
-
Azure resource group name (Hub-based projects only).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionId → String?
-
Azure subscription ID (Hub-based projects only).
final
- timeoutInSeconds → int
-
Request timeout in seconds.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited