DelegatingAIFunctionDeclaration class
An AIFunctionDeclaration that delegates its properties to an inner declaration.
Subclass this to wrap a declaration and override only the properties you need to change.
- Inheritance
-
- Object
- AITool
- AIFunctionDeclaration
- DelegatingAIFunctionDeclaration
- Annotations
-
- @Source(name: 'DelegatingAIFunctionDeclaration.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Functions/')
Constructors
- DelegatingAIFunctionDeclaration(AIFunctionDeclaration inner)
-
Creates a new DelegatingAIFunctionDeclaration wrapping
inner.
Properties
- additionalProperties ↔ AdditionalPropertiesDictionary?
-
Additional properties.
getter/setter pairinherited
- description → String?
-
A description of the tool.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- inner → AIFunctionDeclaration
-
The inner declaration being wrapped.
final
- name → String
-
The name of the tool.
finalinherited
-
parametersSchema
→ Map<
String, dynamic> ? -
The JSON schema describing the function's input parameters.
finalinherited
-
returnSchema
→ Map<
String, dynamic> ? -
The JSON schema describing the function's return value.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getService<
T> ({Object? key}) → T? -
Gets a service of the specified type.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited