DiskBasedResultStore class
Stores ScenarioRunResults as JSON files under storageRootPath.
Layout:
<storageRootPath>/results/<executionName>/<scenarioName>/<iterationName>.json
- Implemented types
- Annotations
-
- @Source(name: 'DiskBasedResultStore.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.Reporting.Storage', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.Reporting.Storage/')
Constructors
- DiskBasedResultStore(String storageRootPath)
-
Creates a DiskBasedResultStore rooted at
storageRootPath.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteResults(
{String? executionName, String? scenarioName, String? iterationName, CancellationToken? cancellationToken}) → Future< void> -
Deletes results, optionally filtered by
executionName,scenarioName, anditerationName.override -
getLatestExecutionNames(
int count, {CancellationToken? cancellationToken}) → Future< List< String> > -
Returns the execution names of the
countmost recent executions, ordered from most recent to least recent.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readResults(
{String? executionName, String? scenarioName, String? iterationName, CancellationToken? cancellationToken}) → Stream< ScenarioRunResult> -
Returns ScenarioRunResults, optionally filtered by
executionName,scenarioName, anditerationName.override -
toString(
) → String -
A string representation of this object.
inherited
-
writeResults(
Iterable< ScenarioRunResult> results, {CancellationToken? cancellationToken}) → Future<void> -
Writes
resultsto the store.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited