EvaluationDiagnostic class

A diagnostic message associated with an EvaluationMetric.

Annotations
  • @Source(name: 'EvaluationDiagnostic.cs', namespace: 'Microsoft.Extensions.AI.Evaluation', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation/')

Constructors

EvaluationDiagnostic(EvaluationDiagnosticSeverity severity, String message)
Creates an EvaluationDiagnostic with the given severity and message.
const
EvaluationDiagnostic.error(String message)
Creates an error diagnostic.
factory
EvaluationDiagnostic.informational(String message)
Creates an informational diagnostic.
factory
EvaluationDiagnostic.warning(String message)
Creates a warning diagnostic.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The diagnostic message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity EvaluationDiagnosticSeverity
The severity of this diagnostic.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited