EvaluationMetricInterpretation class

Specifies how an EvaluationMetric's result should be interpreted.

Annotations
  • @Source(name: 'EvaluationMetricInterpretation.cs', namespace: 'Microsoft.Extensions.AI.Evaluation', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation/')

Constructors

EvaluationMetricInterpretation({EvaluationRating rating = EvaluationRating.unknown, bool failed = false, String? reason})
Creates an EvaluationMetricInterpretation.

Properties

failed bool
Whether the result is considered a failure.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rating EvaluationRating
How good or bad the result is considered.
getter/setter pair
reason String?
Optional commentary on the rating or failure.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited