getLatestExecutionNames abstract method

Future<List<String>> getLatestExecutionNames(
  1. int count, {
  2. CancellationToken? cancellationToken,
})

Returns the execution names of the count most recent executions, ordered from most recent to least recent.

Implementation

Future<List<String>> getLatestExecutionNames(
  int count, {
  CancellationToken? cancellationToken,
});