F1Algorithm class
Computes word-overlap F1 scores.
F1 = 2 * (precision * recall) / (precision + recall), where precision and recall are computed over token multisets.
Reference: Azure AI Evaluation SDK F1 implementation.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited