F1EvaluatorContext class

Contextual information for F1Evaluator: a single ground-truth reference response.

Inheritance
Annotations
  • @Source(name: 'F1EvaluatorContext.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.NLP', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.NLP/')

Constructors

F1EvaluatorContext(String groundTruth)
Creates an F1EvaluatorContext from groundTruth.

Properties

contents List<AIContent>
All contextual information decomposed into AIContent objects.
getter/setter pairinherited
groundTruth String
The reference response to compare against.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name of this context, used as the key in metric context maps.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

groundTruthContextName → const String
Unique context name used when recording contexts on metrics.