GLEUAlgorithm class
Computes Google-BLEU (GLEU) scores.
GLEU measures n-gram overlap across a range of gram sizes, penalizing both under-generation and over-generation.
Reference: NLTK gleu_score implementation.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited