GLEUEvaluatorContext class

Contextual information for GLEUEvaluator: one or more reference responses to compare against.

Inheritance
Annotations
  • @Source(name: 'GLEUEvaluatorContext.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.NLP', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.NLP/')

Constructors

GLEUEvaluatorContext({Iterable<String>? references})
Creates a GLEUEvaluatorContext with the given references.

Properties

contents List<AIContent>
All contextual information decomposed into AIContent objects.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of this context, used as the key in metric context maps.
getter/setter pairinherited
references List<String>
The reference responses against which the evaluated response is compared.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

referencesContextName → const String
Unique context name used when recording contexts on metrics.