GroundednessEvaluatorContext class

Context for GroundednessEvaluator: the grounding information against which fidelity is measured.

Inheritance
Annotations
  • @Source(name: 'GroundednessEvaluatorContext.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.Quality', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.Quality/')

Constructors

GroundednessEvaluatorContext(String groundingContext)
Creates a GroundednessEvaluatorContext from groundingContext.

Properties

contents List<AIContent>
All contextual information decomposed into AIContent objects.
getter/setter pairinherited
groundingContext String
The source material the response should be grounded in.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name of this context, used as the key in metric context maps.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

groundingContextName → const String
Unique context name used when recording contexts on metrics.