HostedFileClientBuilder class
Builds a pipeline of HostedFileClient middleware.
This is an experimental feature.
- Annotations
-
- @Source(name: 'HostedFileClientBuilder.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI/Files/')
Constructors
- HostedFileClientBuilder(HostedFileClient innerClient)
-
Creates a new HostedFileClientBuilder wrapping
innerClient. - HostedFileClientBuilder.fromFactory(InnerHostedFileClientFactory innerFactory)
-
Creates a new HostedFileClientBuilder from a factory function.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
[ServiceProvider? services]) → HostedFileClient - Builds the pipeline and returns the outermost HostedFileClient.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
use(
HostedFileClient factory(HostedFileClient)) → HostedFileClientBuilder - Adds a middleware factory to the pipeline.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited