HostedFileClientMetadata class

Provides metadata about a HostedFileClient.

This is an experimental feature.

Annotations
  • @Source(name: 'HostedFileClientMetadata.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Files/')

Constructors

HostedFileClientMetadata({String? providerName, Uri? providerUri})
Creates a new HostedFileClientMetadata.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
providerName String?
The name of the file storage provider.
final
providerUri Uri?
The URL for accessing the provider.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited