HostedFileClientOptions class
Options for HostedFileClient requests.
This is an experimental feature.
- Annotations
-
- @Source(name: 'HostedFileClientOptions.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Files/')
Constructors
- HostedFileClientOptions({AdditionalPropertiesDictionary? additionalProperties})
-
Creates a new HostedFileClientOptions.
const
Properties
- additionalProperties → AdditionalPropertiesDictionary?
-
Additional properties.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited