ImageGenerationToolResultContent class

Represents the result of an image generation tool invocation by a hosted service.

Outputs are typically DataContent for streamed images or UriContent for remotely hosted images.

Inheritance
Annotations
  • @Source(name: 'ImageGenerationToolResultContent.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Contents/')

Constructors

ImageGenerationToolResultContent({required String callId, List<AIContent>? outputs, Object? rawRepresentation, AdditionalPropertiesDictionary? additionalProperties})
Creates a new ImageGenerationToolResultContent.

Properties

additionalProperties AdditionalPropertiesDictionary?
Additional properties.
getter/setter pairinherited
callId String
The ID of the ToolCallContent this result corresponds to.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
outputs List<AIContent>?
The generated content items (images as DataContent or UriContent).
getter/setter pair
rawRepresentation Object?
The underlying implementation-specific representation of this content.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited