InputRequestContent class
Represents a request for input from the user or application.
The requestId correlates this request with its InputResponseContent.
- Inheritance
- Implementers
- Annotations
-
- @Source(name: 'InputRequestContent.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Contents/')
Constructors
- InputRequestContent({required String requestId, Object? rawRepresentation, AdditionalPropertiesDictionary? additionalProperties})
- Creates a new InputRequestContent.
Properties
- additionalProperties ↔ AdditionalPropertiesDictionary?
-
Additional properties.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- rawRepresentation ↔ Object?
-
The underlying implementation-specific representation of this content.
getter/setter pairinherited
- requestId → String
-
Unique identifier correlating this request with its response.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited