InputResponseContent class

Represents the response to an InputRequestContent.

The requestId correlates this response with its originating request.

Inheritance
Implementers
Annotations
  • @Source(name: 'InputResponseContent.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Contents/')

Constructors

InputResponseContent({required String requestId, Object? rawRepresentation, AdditionalPropertiesDictionary? additionalProperties})
Creates a new InputResponseContent.

Properties

additionalProperties AdditionalPropertiesDictionary?
Additional properties.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
rawRepresentation Object?
The underlying implementation-specific representation of this content.
getter/setter pairinherited
requestId String
Unique identifier correlating this response with its request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited