IntentResolutionEvaluatorContext class

Context for IntentResolutionEvaluator: the tool definitions used when generating the response.

Only AIFunctionDeclaration tools are currently evaluated.

Inheritance
Annotations
  • @Source(name: 'IntentResolutionEvaluatorContext.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.Quality', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.Quality/')

Constructors

IntentResolutionEvaluatorContext({List<AITool>? toolDefinitions})
Creates an IntentResolutionEvaluatorContext with toolDefinitions.

Properties

contents List<AIContent>
All contextual information decomposed into AIContent objects.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of this context, used as the key in metric context maps.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolDefinitions List<AITool>
The tool definitions available when generating the response.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

toolDefinitionsContextName → const String
Unique context name used when recording contexts on metrics.