McpServerToolCallContent class

Represents a tool call request to an MCP server by a hosted service.

This is informational only — it may appear as part of an approval request or as a record of which MCP server tool was invoked.

Inheritance
Annotations
  • @Source(name: 'McpServerToolCallContent.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Contents/')

Constructors

McpServerToolCallContent({required String callId, required String toolName, String? serverName, Map<String, Object?>? arguments, Object? rawRepresentation, AdditionalPropertiesDictionary? additionalProperties})
Creates a new McpServerToolCallContent.

Properties

additionalProperties AdditionalPropertiesDictionary?
Additional properties.
getter/setter pairinherited
arguments Map<String, Object?>?
The arguments to pass to the tool.
getter/setter pair
callId String
The unique identifier for this tool call.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
rawRepresentation Object?
The underlying implementation-specific representation of this content.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverName String?
The name of the MCP server that hosts the tool.
final
toolName String
The name of the MCP tool being called.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited