NGram<T> class

An n-gram: a contiguous sequence of n tokens.

Constructors

NGram(List<T> values)
Creates an NGram from values.

Properties

hashCode int
The hash code for this object.
no setteroverride
length int
The number of tokens in this n-gram.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override
operator [](int index) → T
Returns the token at index.