ReasoningEffort enum

Specifies the level of reasoning effort to apply when generating responses.

Higher values may produce more thoughtful responses but with increased latency and token usage. Support for each level varies by provider.

Inheritance
Available extensions
Annotations
  • @Source(name: 'ReasoningEffort.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/ChatCompletion/')

Values

none → const ReasoningEffort

No reasoning effort.

low → const ReasoningEffort

Minimal reasoning for faster responses.

medium → const ReasoningEffort

Balanced reasoning for most use cases.

high → const ReasoningEffort

Extensive reasoning for complex tasks.

extraHigh → const ReasoningEffort

Maximum reasoning for the most demanding tasks.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ReasoningEffort>
A constant List of the values in this enum, in order of their declaration.