ReasoningOutput enum

Specifies how reasoning content should be included in the response.

Some providers support including reasoning or thinking traces in the response. This controls whether and how that content is exposed.

Inheritance
Available extensions
Annotations
  • @Source(name: 'ReasoningOutput.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/ChatCompletion/')

Values

none → const ReasoningOutput

Do not include reasoning content in the response.

summary → const ReasoningOutput

Include a summary of the reasoning process.

full → const ReasoningOutput

Include all reasoning content in the response.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ReasoningOutput>
A constant List of the values in this enum, in order of their declaration.