get abstract method
Returns the cached ChatResponse for key, or null if not found or
expired.
Implementation
Future<ChatResponse?> get(String key);
Returns the cached ChatResponse for key, or null if not found or
expired.
Future<ChatResponse?> get(String key);