setCachedResponse method
Stores a response in the cache with the given key.
Implementation
@override
Future<void> setCachedResponse(String key, ChatResponse response) =>
_cache.set(key, response);
Stores a response in the cache with the given key.
@override
Future<void> setCachedResponse(String key, ChatResponse response) =>
_cache.set(key, response);