RetrievalEvaluatorContext class

Context for RetrievalEvaluator: the retrieved context chunks to assess.

Inheritance
Annotations
  • @Source(name: 'RetrievalEvaluatorContext.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.Quality', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.Quality/')

Constructors

RetrievalEvaluatorContext({List<String>? retrievedContextChunks})
Creates a RetrievalEvaluatorContext from retrievedContextChunks.

Properties

contents List<AIContent>
All contextual information decomposed into AIContent objects.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of this context, used as the key in metric context maps.
getter/setter pairinherited
retrievedContextChunks List<String>
The context chunks retrieved in response to the user request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

retrievedContextChunksContextName → const String
Unique context name used when recording contexts on metrics.