ScenarioRunResult class
The persisted result of a single ScenarioRun evaluation.
- Annotations
-
- @Source(name: 'ScenarioRunResult.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.Reporting', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.Reporting/')
Constructors
-
ScenarioRunResult({required String scenarioName, required String iterationName, required String executionName, required DateTime creationTime, required List<
ChatMessage> messages, required ChatResponse modelResponse, required EvaluationResult evaluationResult, ChatDetails? chatDetails, List<String> ? tags, int? formatVersion = 1}) - Creates a ScenarioRunResult.
Properties
- chatDetails ↔ ChatDetails?
-
Details of LLM turns during this run;
nullif no AI evaluators ran.getter/setter pair - creationTime ↔ DateTime
-
Time at which this result was created.
getter/setter pair
- evaluationResult ↔ EvaluationResult
-
The evaluation result for this scenario run.
getter/setter pair
- executionName ↔ String
-
The execution name shared by all scenario runs in a single evaluation
run.
getter/setter pair
- formatVersion ↔ int?
-
Format version for persistence compatibility.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- iterationName ↔ String
-
The iteration name within the scenario.
getter/setter pair
-
messages
↔ List<
ChatMessage> -
The conversation history that produced modelResponse.
getter/setter pair
- modelResponse ↔ ChatResponse
-
The model response being evaluated.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scenarioName ↔ String
-
The scenario name.
getter/setter pair
-
Optional tags for this result.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited