TextToSpeechClientMetadata class

Provides metadata about a TextToSpeechClient.

This is an experimental feature.

Annotations
  • @Source(name: 'TextToSpeechClientMetadata.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/TextToSpeech/')

Constructors

TextToSpeechClientMetadata({String? providerName, Uri? providerUri, String? defaultModelId})
Creates a new TextToSpeechClientMetadata.
const

Properties

defaultModelId String?
The default model ID used by this client.
final
hashCode int
The hash code for this object.
no setterinherited
providerName String?
The name of the text-to-speech provider.
final
providerUri Uri?
The URL for accessing the provider.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited