TextToSpeechResponse class
The result of a text-to-speech request.
This is an experimental feature.
- Annotations
-
- @Source(name: 'TextToSpeechResponse.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/TextToSpeech/')
Constructors
- TextToSpeechResponse({DataContent? audio, String? responseId, String? modelId, UsageDetails? usage, Object? rawRepresentation, AdditionalPropertiesDictionary? additionalProperties})
- Creates a new TextToSpeechResponse.
Properties
- additionalProperties ↔ AdditionalPropertiesDictionary?
-
Additional properties.
getter/setter pair
- audio ↔ DataContent?
-
The generated audio content.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- modelId ↔ String?
-
The model that generated this response.
getter/setter pair
- rawRepresentation ↔ Object?
-
The underlying implementation-specific object.
getter/setter pair
- responseId ↔ String?
-
A unique identifier for this response.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usage ↔ UsageDetails?
-
Usage details for the request/response.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited