ToolCallContent class abstract

Base class for content types that represent a tool call request.

Inheritance
Implementers
Annotations
  • @Source(name: 'ToolCallContent.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Contents/')

Constructors

ToolCallContent({required String callId, Object? rawRepresentation, AdditionalPropertiesDictionary? additionalProperties})
Creates a new ToolCallContent.

Properties

additionalProperties AdditionalPropertiesDictionary?
Additional properties.
getter/setter pairinherited
callId String
The unique identifier for this tool call.
final
hashCode int
The hash code for this object.
no setterinherited
rawRepresentation Object?
The underlying implementation-specific representation of this content.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited