WebSearchToolResultContent class
Represents the result of a web search tool invocation by a hosted service.
Each output typically represents a web page result, usually as a
UriContent. A title may be stored in AIContent.additionalProperties
under the key "title".
- Inheritance
-
- Object
- AIContent
- ToolResultContent
- WebSearchToolResultContent
- Annotations
-
- @Source(name: 'WebSearchToolResultContent.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Contents/')
Constructors
-
WebSearchToolResultContent({required String callId, List<
AIContent> ? outputs, Object? rawRepresentation, AdditionalPropertiesDictionary? additionalProperties}) - Creates a new WebSearchToolResultContent.
Properties
- additionalProperties ↔ AdditionalPropertiesDictionary?
-
Additional properties.
getter/setter pairinherited
- callId → String
-
The ID of the ToolCallContent this result corresponds to.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
outputs
↔ List<
AIContent> ? -
The web search result items (typically UriContent instances).
getter/setter pair
- rawRepresentation ↔ Object?
-
The underlying implementation-specific representation of this content.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited