Source class

Annotation used for tracking source information.

Constructors

Source({required String name, required String namespace, required String repository, required String path, String? alias, String? commit, String? notes})
const

Properties

alias → String?
final
commit → String?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
namespace → String
final
notes → String?
final
path → String
final
repository → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited