BufferedLogRecordImpl class

Default implementation of BufferedLogRecord.

Implemented types

Constructors

BufferedLogRecordImpl({required DateTime timestamp, required LogLevel logLevel, required EventId eventId, String? exception, String? activitySpanId, String? activityTraceId, String? formattedMessage, String? messageTemplate, List<MapEntry<String, Object?>>? attributes})
Creates a new instance of BufferedLogRecordImpl.

Properties

activitySpanId → String?
Gets an activity span ID for this record, representing the state of the thread that created the record.
final
activityTraceId → String?
Gets an activity trace ID for this record, representing the state of the thread that created the record.
final
attributes → List<MapEntry<String, Object?>>
Gets the variable set of name/value pairs associated with the record.
final
eventId → EventId
Gets the record's event ID.
final
exception → String?
Gets an exception string for this record.
final
formattedMessage → String?
Gets the formatted log message.
final
hashCode → int
The hash code for this object.
no setterinherited
logLevel → LogLevel
Gets the record's logging severity level.
final
messageTemplate → String?
Gets the original log message template.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
Gets the time when the log record was first created.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited