CancellationCallbackInfo class

Constructors

CancellationCallbackInfo({required int id, required CancellationCallback callback, required Registrations registrations, Object? stateForCallback, CancellationTokenSource? cancellationTokenSource})

Properties

callback → CancellationCallback
no setter
cancellationTokenSource → CancellationTokenSource?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
registrations → Registrations
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → dynamic
no setter

Methods

executeCallback() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited