ChatResponseUpdatesStreamExtensions extension

Provides extension methods for combining a stream of ChatResponseUpdate instances into a ChatResponse.

on

Methods

toChatResponse() Future<ChatResponse>

Available on Stream<ChatResponseUpdate>, provided by the ChatResponseUpdatesStreamExtensions extension

Drains the stream and combines the updates into a single ChatResponse.