EqualToFilterClause class final

A filter clause that matches records where a field equals a specific value.

Deprecated — use VectorStoreFilter.equalTo instead.

Inheritance
Annotations
  • @Deprecated('Use VectorStoreFilter.equalTo() instead.')
  • @Source(name: 'EqualToFilterClause.cs', namespace: 'Microsoft.Extensions.VectorData', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.VectorData.Abstractions/VectorData/FilterClauses/')

Constructors

EqualToFilterClause(String fieldName, Object? value)
Creates an EqualToFilterClause.
const

Properties

fieldName String
The name of the field to compare.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
The value the field must equal.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited