EqualToVectorStoreFilter class final

A filter that matches records where a field equals a specific value.

Inheritance

Constructors

EqualToVectorStoreFilter(String fieldName, Object? value)
Creates an EqualToVectorStoreFilter.
const

Properties

fieldName String
The name of the field to compare.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
The value the field must equal.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited