FileConfigurationProvider class abstract

Provides the base class for file-based ConfigurationProvider providers.

Inheritance
Implemented types
Mixed-in types
Implementers

Constructors

FileConfigurationProvider(FileConfigurationSource source)
Initializes a new instance with the specified source.

Properties

data LinkedHashMap<String, String?>
The configuration key value pairs for this provider.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source FileConfigurationSource
Gets the source settings for this provider.
no setter

Methods

dispose() → void
Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.
override
getChildKeys(Iterable<String> earlierKeys, String? parentPath) Iterable<String>
Returns the list of keys that this provider has.
inherited
getReloadToken() ChangeToken
Returns a ChangeToken that can be used to listen when this provider is reloaded.
inherited
load() → void
Loads the contents of the file at FileConfigurationSource.path.
override
loadFromFile(FileInfo file) → void
Loads this provider's data from a file path.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onReload() → void
Triggers the reload change token and creates a new one.
inherited
set(String key, String? value) → void
Sets a value for a given key.
inherited
toString() String
Generates a string representing this provider name and relevant details.
override
tryGet(String key) → (bool, String?)
Tries to get a configuration value for the specified key.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited