onLoadException property
Gets or sets the action that's called if an uncaught exception occurs in FileConfigurationProvider.load.
Implementation
void Function(FileLoadExceptionContext context)? onLoadException;
Gets or sets the action that's called if an uncaught exception occurs in FileConfigurationProvider.load.
void Function(FileLoadExceptionContext context)? onLoadException;