reloadOnChange property

bool reloadOnChange
getter/setter pair

Gets or sets a value that indicates whether the source will be loaded if the underlying file changes.

Implementation

bool reloadOnChange = false;