FileLoadExceptionContext class

Contains information about a file load exception.

Constructors

FileLoadExceptionContext()

Properties

exception Exception
Gets or sets the exception that occurred in Load.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ignore bool
Gets or sets a value that indicates whether the exception is rethrown.
getter/setter pair
provider FileConfigurationProvider
Gets or sets the FileConfigurationProvider that caused the exception.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited