FileSystemException class

An exception thrown when a file-based configuration source cannot be read.

This is a web-safe stand-in for dart:io's FileSystemException so that file-based configuration can be used on platforms without dart:io.

Implemented types

Constructors

FileSystemException(String message, [String? path])
Creates a FileSystemException with a message and optional path.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A description of the error.
final
path String?
The path of the file that triggered the error, if known.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited