FunctionCallContent class

Represents a request from the model to invoke a function.

Inheritance

Constructors

FunctionCallContent({required String callId, required String name, Map<String, Object?>? arguments})
Creates a new FunctionCallContent.

Properties

additionalProperties AdditionalPropertiesDictionary?
Additional properties.
getter/setter pairinherited
arguments AdditionalPropertiesDictionary?
The arguments to pass to the function.
final
callId String
The unique identifier for this function call.
final
exception Exception?
An exception that occurred while parsing the arguments.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the function to invoke.
final
rawRepresentation Object?
The underlying implementation-specific representation of this content.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited