getService<T> method
Asks the session for an object of the specified type T.
Returns the found object, or null if no matching service is available.
Implementation
@override
T? getService<T>({Object? key}) => _innerSession.getService<T>(key: key);