FunctionResultContent class

Represents the result of a function call.

Inheritance

Constructors

FunctionResultContent({required String callId, String? name, Object? result, Exception? exception})
Creates a new FunctionResultContent.

Properties

additionalProperties AdditionalPropertiesDictionary?
Additional properties.
getter/setter pairinherited
callId String
The call ID corresponding to the function call this is a result for.
final
exception Exception?
An exception that occurred during function execution.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
The name of the function that was called.
final
rawRepresentation Object?
The underlying implementation-specific representation of this content.
getter/setter pairinherited
result Object?
The result of the function call.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited