HttpClientLogger class abstract

An abstraction for custom HTTP request logging for named HTTP client instances returned by HttpClientFactory.

Implementers

Constructors

HttpClientLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

logRequestFailed(Object? context, BaseRequest? request, Exception exception, Duration elapsed) → void
Logs the exception happened while sending an HTTP request.
logRequestStart(BaseRequest request) Object?
Logs before sending an HTTP request.
logRequestStop(Object? context, BaseRequest response, Duration elapsed) → void
Logs after receiving an HTTP response.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited