MemoryConfigurationSource class

Represents in-memory data as an ConfigurationSource.

Implemented types

Constructors

MemoryConfigurationSource([Iterable<MapEntry<String, String?>>? initialData])

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialData ↔ Iterable<MapEntry<String, String?>>?
The initial key value configuration pairs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(ConfigurationBuilder builder) → ConfigurationProvider
Builds the MemoryConfigurationProvider for this source.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited