MemoryDistributedCacheOptions class

Provides configuration options for the memory-backed implementation of the distributed cache.

Inheritance

Properties

compactionPercentage double
Gets or sets the amount to compact the cache by when the maximum size is exceeded.
getter/setter pairinherited
expirationScanFrequency Duration
Gets or sets the minimum length of time between successive scans for expired items.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeLimit int?
Gets or sets the maximum size of the cache.
getter/setter pairinherited
trackLinkedCacheEntries bool
Gets or sets a value that determines whether cache entries should track hierarchical relationships.
getter/setter pairinherited
trackStatistics bool
Gets or sets a value that determines whether statistics should be collected for the cache.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited