NotFoundFileInfo class

Represents a non-existing file.

Implemented types

Constructors

NotFoundFileInfo(String name)
Initializes an instance of NotFoundFileInfo.

Properties

exists → bool
Always false.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isDirectory → bool
Always false.
no setteroverride
lastModified → DateTime
Returns a negative infinity date value.
no setteroverride
length → int
Always equals -1.
no setteroverride
name → String
The name of the file or directory, not including any path.
no setteroverride
physicalPath → String?
Always null.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createReadStream() → Stream
Always throws. A stream cannot be created for a non-existing file.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited