OpenTelemetryConsts class abstract final

Semantic convention constants for AI telemetry spans and attributes.

These values follow the OpenTelemetry Semantic Conventions for Generative AI systems. Wire these up to an actual OpenTelemetry SDK when available.

Annotations
  • @Source(name: 'OpenTelemetryConsts.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI/')

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

chatSpanName → const String
embeddingsSpanName → const String
errorTypeKey → const String
executeToolSpanName → const String
fileNameKey → const String
filesDeleteSpanName → const String
filesDownloadSpanName → const String
filesGetSpanName → const String
filesIdKey → const String
filesListSpanName → const String
filesMediaTypeKey → const String
filesOperationNameKey → const String
filesUploadSpanName → const String
finishReasonKey → const String
genAICaptureMessageContentEnvVar → const String
Environment variable upstream reads to default enableSensitiveData.
imageGenerationSpanName → const String
inputMessagesKey → const String
inputTokensKey → const String
operationDurationBuckets → const List<double>
Histogram bucket boundaries for operation duration (seconds).
operationNameKey → const String
outputMessagesKey → const String
outputModalitiesKey → const String
outputTokensKey → const String
realtimeSpanName → const String
requestMaxTokensKey → const String
requestModelKey → const String
requestTemperatureKey → const String
requestTopKKey → const String
requestTopPKey → const String
responseIdKey → const String
responseModelKey → const String
serverAddressKey → const String
sessionKindKey → const String
speechToTextSpanName → const String
systemKey → const String
textToSpeechSpanName → const String
toolCallArgumentsKey → const String
toolCallIdKey → const String
toolCallResultKey → const String
toolDescriptionKey → const String
toolNameKey → const String
toolTypeFunction → const String
The gen_ai.tool.type value for function tools.
toolTypeKey → const String
voiceKey → const String