OrVectorStoreFilter class final
A filter that requires at least one of filters to match.
- Inheritance
-
- Object
- VectorStoreFilter
- OrVectorStoreFilter
Constructors
-
OrVectorStoreFilter(List<
VectorStoreFilter> filters) -
Creates an OrVectorStoreFilter.
const
Properties
-
filters
→ List<
VectorStoreFilter> -
The filters of which at least one must match.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited