modelName property
The model name of the property.
When the property corresponds to a record field, this is that field's name.
Implementation
String modelName;
The model name of the property.
When the property corresponds to a record field, this is that field's name.
String modelName;