RealtimeSessionKind class

Represents the kind of a real-time session.

This is an experimental feature.

Annotations
  • @Source(name: 'RealtimeSessionKind.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Realtime/', commit: '2e537166e4231e50cceb66832b9dfd1382e24d1b')

Constructors

RealtimeSessionKind(String value)
Creates a new RealtimeSessionKind with the given value.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The value associated with this session kind.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

conversation → const RealtimeSessionKind
A conversation session.
transcription → const RealtimeSessionKind
A transcription-only session.