SessionUpdateRealtimeClientMessage class
A client message that updates the session options.
This is an experimental feature.
- Inheritance
-
- Object
- RealtimeClientMessage
- SessionUpdateRealtimeClientMessage
- Annotations
-
- @Source(name: 'SessionUpdateRealtimeClientMessage.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Realtime/', commit: '2e537166e4231e50cceb66832b9dfd1382e24d1b')
Constructors
- SessionUpdateRealtimeClientMessage(RealtimeSessionOptions options)
-
Creates a new SessionUpdateRealtimeClientMessage with the given
options.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId ↔ String?
-
The optional message ID associated with the message.
getter/setter pairinherited
- options ↔ RealtimeSessionOptions
-
The session options to apply.
getter/setter pair
- rawRepresentation ↔ Object?
-
The raw representation of the message.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited