StringComparison enum

Specifies how two strings are compared during pattern matching.

Mirrors the subset of .NET StringComparison values supported by Microsoft.Extensions.FileSystemGlobbing.

Inheritance
Available extensions

Values

ordinal → const StringComparison

Compare strings using ordinal (binary) sort rules.

ordinalIgnoreCase → const StringComparison

Compare strings using ordinal (binary) sort rules, ignoring case.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StringComparison>
A constant List of the values in this enum, in order of their declaration.