tryGetResult method
T?
tryGetResult()
Attempts to deserialize the result, returning null on any failure.
Implementation
T? tryGetResult() {
try {
return _getResultCore();
} catch (_) {
return null;
}
}
Attempts to deserialize the result, returning null on any failure.
T? tryGetResult() {
try {
return _getResultCore();
} catch (_) {
return null;
}
}