ensureCollectionExistsAsync abstract method
Creates the collection in the vector store if it does not already exist.
Implementation
Future<void> ensureCollectionExistsAsync({
CancellationToken? cancellationToken,
});
Creates the collection in the vector store if it does not already exist.
Future<void> ensureCollectionExistsAsync({
CancellationToken? cancellationToken,
});