VectorStoreCollectionMetadata class
Metadata about a vector store collection.
- Annotations
-
- @Source(name: 'VectorStoreCollectionMetadata.cs', namespace: 'Microsoft.Extensions.VectorData', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.VectorData.Abstractions/VectorData/')
Constructors
- VectorStoreCollectionMetadata({String? vectorStoreSystemName, String? vectorStoreName, String? collectionName})
-
Creates a VectorStoreCollectionMetadata.
const
Properties
- collectionName → String?
-
The name of the collection.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vectorStoreName → String?
-
The name of the vector store instance.
final
- vectorStoreSystemName → String?
-
The system name of the vector store (e.g.,
'Redis','Qdrant').final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited