VectorStoreDataProperty class final

Defines a data property in a vector store record.

Data properties store the non-vector payload fields of a record.

Inheritance
Annotations
  • @Source(name: 'VectorStoreDataProperty.cs', namespace: 'Microsoft.Extensions.VectorData', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.VectorData.Abstractions/VectorData/RecordDefinition/')

Constructors

VectorStoreDataProperty(String propertyName)
Creates a VectorStoreDataProperty for propertyName.

Properties

hashCode int
The hash code for this object.
no setterinherited
isFullTextIndexed bool
Whether the property should be indexed for full-text search.
getter/setter pair
isIndexed bool
Whether the property should be indexed for filtering.
getter/setter pair
propertyName String
The name of the property on the record model.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageName String?
The name used when storing this property in the vector store.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited