VectorStoreException class

Represents an error that occurred while interacting with a vector store.

Implemented types
Annotations
  • @Source(name: 'VectorStoreException.cs', namespace: 'Microsoft.Extensions.VectorData', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.VectorData.Abstractions/VectorData/')

Constructors

VectorStoreException([String? message])
Creates a VectorStoreException.
VectorStoreException.withCause(String? message, Object? cause)
Creates a VectorStoreException with a message and inner cause.

Properties

cause Object?
The underlying cause of this exception, if any.
final
collectionName String?
The name of the collection that was being operated on.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String?
The error message.
final
operationName String?
The name of the operation that was being performed.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vectorStoreName String?
The name of the vector store instance.
getter/setter pair
vectorStoreSystemName String?
The system name of the vector store (e.g., 'Redis', 'Qdrant').
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited