VectorStoreKeyProperty class final
Defines a key property in a vector store record.
Exactly one VectorStoreKeyProperty must appear in a VectorStoreCollectionDefinition.
- Inheritance
-
- Object
- VectorStoreProperty
- VectorStoreKeyProperty
- Annotations
-
- @Source(name: 'VectorStoreKeyProperty.cs', namespace: 'Microsoft.Extensions.VectorData', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.VectorData.Abstractions/VectorData/RecordDefinition/')
Constructors
- VectorStoreKeyProperty(String propertyName)
-
Creates a VectorStoreKeyProperty for
propertyName.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- propertyName → String
-
The name of the property on the record model.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageName ↔ String?
-
The name used when storing this property in the vector store.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited