VoiceActivityDetectionOptions class

Represents voice activity detection (VAD) options for a real-time session.

This is an experimental feature.

Annotations
  • @Source(name: 'VoiceActivityDetectionOptions.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Realtime/', commit: '2e537166e4231e50cceb66832b9dfd1382e24d1b')

Constructors

VoiceActivityDetectionOptions({bool enabled = true, bool allowInterruption = true})
Creates a new VoiceActivityDetectionOptions.

Properties

allowInterruption bool
Whether the user is allowed to interrupt the model.
getter/setter pair
enabled bool
Whether voice activity detection is enabled.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited