AIFunctionFactoryOptions class

Options for controlling how AIFunctionFactory creates an AIFunction.

Annotations
  • @Source(name: 'AIFunctionFactoryOptions.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Functions/')

Constructors

AIFunctionFactoryOptions({String? name, String? description, AdditionalPropertiesDictionary? additionalProperties})
Creates a new AIFunctionFactoryOptions.
const

Properties

additionalProperties AdditionalPropertiesDictionary?
Additional properties to store on the resulting function.
final
description String?
An override for the function description.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
An override for the function name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited