AutoChatToolMode class final
Indicates that a chat client is free to select any of the available tools, or none at all.
Use ChatToolMode.auto to get an instance of AutoChatToolMode.
- Inheritance
-
- Object
- ChatToolMode
- AutoChatToolMode
- Annotations
-
- @Source(name: 'AutoChatToolMode.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/ChatCompletion/', commit: '01a52dd763da02f75bf1cd604e98c3e7c8508a5d')
Constructors
- AutoChatToolMode()
-
Creates a new AutoChatToolMode.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override