ChatDetails class
Records details for all LLM chat turns in a ScenarioRun execution.
- Annotations
-
- @Source(name: 'ChatDetails.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.Reporting', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.Reporting/')
Constructors
-
ChatDetails({List<
ChatTurnDetails> ? turnDetails}) -
Creates ChatDetails with an optional initial list of
turnDetails.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
turnDetails
↔ List<
ChatTurnDetails> -
Turn-by-turn details recorded during the scenario run.
getter/setter pair
Methods
-
addTurnDetails(
ChatTurnDetails details) → void -
Appends
detailsto turnDetails. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited