ChatReducer class abstract
Reduces a list of chat messages (e.g. for context window management).
This is an experimental feature.
- Implementers
- Annotations
-
- @Source(name: 'IChatReducer.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/ChatReduction/', commit: 'a144ceba8f9bc2241b86352f8e97ba68f82df217')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reduce(
List< ChatMessage> messages, {CancellationToken? cancellationToken}) → Future<List< ChatMessage> > -
Reduces the given
messages. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited