ChatTurnDetails class
Details for a single LLM chat conversation turn in a ScenarioRun.
- Annotations
-
- @Source(name: 'ChatTurnDetails.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.Reporting', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.Reporting/')
Constructors
- ChatTurnDetails({required Duration latency, String? model, String? modelProvider, UsageDetails? usage, String? cacheKey, bool? cacheHit})
- Creates ChatTurnDetails.
Properties
- cacheHit ↔ bool?
-
Whether the response was a cache hit;
nullwhen caching is disabled.getter/setter pair - cacheKey ↔ String?
-
Cache key when response caching is enabled;
nullotherwise.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- latency ↔ Duration
-
Time between the request being sent and the response being received.
getter/setter pair
- model ↔ String?
-
Model that produced the response, or
nullif unavailable.getter/setter pair - modelProvider ↔ String?
-
Provider of model, or
nullif unavailable.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usage ↔ UsageDetails?
-
Token usage for this turn, or
nullif unavailable.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited