CodeInterpreterToolCallContent class
Represents a code interpreter tool call invoked by a hosted service.
This is informational only and represents the call itself, not its result.
Inputs typically include a DataContent with media type text/x-python.
- Inheritance
-
- Object
- AIContent
- ToolCallContent
- CodeInterpreterToolCallContent
- Annotations
-
- @Source(name: 'CodeInterpreterToolCallContent.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Contents/')
Constructors
-
CodeInterpreterToolCallContent({required String callId, List<
AIContent> ? inputs, Object? rawRepresentation, AdditionalPropertiesDictionary? additionalProperties}) - Creates a new CodeInterpreterToolCallContent.
Properties
- additionalProperties ↔ AdditionalPropertiesDictionary?
-
Additional properties.
getter/setter pairinherited
- callId → String
-
The unique identifier for this tool call.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputs
↔ List<
AIContent> ? -
The inputs provided to the code interpreter tool.
getter/setter pair
- rawRepresentation ↔ Object?
-
The underlying implementation-specific representation of this content.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited