DiskBasedReportingConfiguration class

Factory for a fully disk-backed ReportingConfiguration.

Annotations
  • @Source(name: 'DiskBasedReportingConfiguration.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.Reporting.Storage', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.Reporting.Storage/')

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(String storageRootPath, Iterable<Evaluator> evaluators, {ChatConfiguration? chatConfiguration, bool enableResponseCaching = false, Duration responseTimeToLive = const Duration(days: 14), Iterable<String>? cachingKeys, String? executionName, EvaluationMetricInterpretation? evaluationMetricInterpreter(EvaluationMetric)?, Iterable<String>? tags}) ReportingConfiguration
Creates a ReportingConfiguration that persists ScenarioRunResults and optionally caches AI responses on disk under storageRootPath.