EvaluationRating enum
Identifies how the result of an evaluation should be interpreted.
Values
- unknown → const EvaluationRating
-
The rating cannot be determined.
- inconclusive → const EvaluationRating
-
The result cannot be interpreted conclusively.
- unacceptable → const EvaluationRating
-
The result is considered unacceptable.
- poor → const EvaluationRating
-
The result is considered poor.
- average → const EvaluationRating
-
The result is considered average.
- good → const EvaluationRating
-
The result is considered good.
- exceptional → const EvaluationRating
-
The result is considered exceptional.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
EvaluationRating> - A constant List of the values in this enum, in order of their declaration.