EvaluationResultStore class abstract
Stores and retrieves ScenarioRunResults from a backing store.
- Implementers
- Annotations
-
- @Source(name: 'IEvaluationResultStore.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.Reporting', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.Reporting/')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteResults(
{String? executionName, String? scenarioName, String? iterationName, CancellationToken? cancellationToken}) → Future< void> -
Deletes results, optionally filtered by
executionName,scenarioName, anditerationName. -
getLatestExecutionNames(
int count, {CancellationToken? cancellationToken}) → Future< List< String> > -
Returns the execution names of the
countmost recent executions, ordered from most recent to least recent. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readResults(
{String? executionName, String? scenarioName, String? iterationName, CancellationToken? cancellationToken}) → Stream< ScenarioRunResult> -
Returns ScenarioRunResults, optionally filtered by
executionName,scenarioName, anditerationName. -
toString(
) → String -
A string representation of this object.
inherited
-
writeResults(
Iterable< ScenarioRunResult> results, {CancellationToken? cancellationToken}) → Future<void> -
Writes
resultsto the store.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited