Semantic convention constants for AI telemetry spans and attributes.
These values follow the OpenTelemetry Semantic Conventions for Generative AI systems. Wire these up to an actual OpenTelemetry SDK when available.
- Annotations
-
- @Source(name: 'OpenTelemetryConsts.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI/')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- chatSpanName → const String
- embeddingsSpanName → const String
- errorTypeKey → const String
- finishReasonKey → const String
- imageGenerationSpanName → const String
- inputTokensKey → const String
-
operationDurationBuckets
→ const List<
double> - Histogram bucket boundaries for operation duration (seconds).
- outputTokensKey → const String
- requestMaxTokensKey → const String
- requestModelKey → const String
- requestTemperatureKey → const String
- requestTopKKey → const String
- requestTopPKey → const String
- responseIdKey → const String
- responseModelKey → const String
- serverAddressKey → const String
- systemKey → const String
- textToSpeechSpanName → const String