OpenTelemetryTextToSpeechClient class
A DelegatingTextToSpeechClient that records OpenTelemetry spans.
- Inheritance
-
- Object
- DelegatingTextToSpeechClient
- OpenTelemetryTextToSpeechClient
- Annotations
-
- @Source(name: 'OpenTelemetryTextToSpeechClient.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI/TextToSpeech/')
Constructors
- OpenTelemetryTextToSpeechClient(TextToSpeechClient innerClient, {String? modelId, String? system})
- Creates a new OpenTelemetryTextToSpeechClient.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- innerClient → TextToSpeechClient
-
The inner client to delegate to.
finalinherited
- modelId → String?
-
The model ID to record on spans.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- system → String?
-
The AI system name (e.g.
"openai").final
Methods
-
dispose(
) → void -
Performs application-defined tasks associated with freeing, releasing,
or resetting unmanaged resources.
inherited
-
getAudio(
String text, {TextToSpeechOptions? options, CancellationToken? cancellationToken}) → Future< TextToSpeechResponse> -
Synthesizes
textinto audio and returns the complete response.override -
getService<
T> ({Object? key}) → T? -
Gets a service of the specified type.
inherited
-
getStreamingAudio(
String text, {TextToSpeechOptions? options, CancellationToken? cancellationToken}) → Stream< TextToSpeechResponseUpdate> -
Synthesizes
textinto audio and returns a stream of response updates.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited