ReasoningOptions class
Options for configuring reasoning behavior in chat requests.
Not all providers support all reasoning options. Implementations should make a best-effort attempt to map these options to provider capabilities. If a provider does not support reasoning, these options may be ignored.
- Annotations
-
- @Source(name: 'ReasoningOptions.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/ChatCompletion/')
Constructors
- ReasoningOptions({ReasoningEffort? effort, ReasoningOutput? output})
- Creates a new ReasoningOptions.
Properties
- effort ↔ ReasoningEffort?
-
The level of reasoning effort to apply.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- output ↔ ReasoningOutput?
-
How reasoning content should be included in the response.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clone(
) → ReasoningOptions - Creates a shallow clone of this ReasoningOptions.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited