RelevanceTruthAndCompletenessRating class
The structured JSON response from RelevanceTruthAndCompletenessEvaluator.
Holds scores (1–5) and reasoning for all three evaluation dimensions.
- Annotations
-
- @Source(name: 'RelevanceTruthAndCompletenessRating.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.Quality', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.Quality/')
Constructors
-
RelevanceTruthAndCompletenessRating({required int relevance, String? relevanceReasoning, List<
String> ? relevanceReasons, required int truth, String? truthReasoning, List<String> ? truthReasons, required int completeness, String? completenessReasoning, List<String> ? completenessReasons}) - Creates a RelevanceTruthAndCompletenessRating.
-
RelevanceTruthAndCompletenessRating.fromJson(Map<
String, dynamic> j) -
Deserializes from a JSON map.
factory
Properties
- completeness → int
-
Completeness score (1–5).
final
- completenessReasoning → String?
-
Reasoning for the completeness score.
final
-
completenessReasons
→ List<
String> -
Category labels for the completeness reasoning.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInconclusive → bool
-
trueif any score is outside the valid 1–5 range.no setter - relevance → int
-
Relevance score (1–5).
final
- relevanceReasoning → String?
-
Reasoning for the relevance score.
final
-
relevanceReasons
→ List<
String> -
Category labels for the relevance reasoning.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- truth → int
-
Truth score (1–5).
final
- truthReasoning → String?
-
Reasoning for the truth score.
final
-
truthReasons
→ List<
String> -
Category labels for the truth reasoning.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
tryParse(
String raw) → RelevanceTruthAndCompletenessRating? - Parses a RelevanceTruthAndCompletenessRating from a JSON string.