ReportingConfiguration class
Bundles all configuration needed to create ScenarioRun instances for an evaluation batch.
- Annotations
-
- @Source(name: 'ReportingConfiguration.cs', namespace: 'Microsoft.Extensions.AI.Evaluation.Reporting', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Evaluation.Reporting/')
Constructors
-
ReportingConfiguration(Iterable<
Evaluator> evaluators, EvaluationResultStore resultStore, {ChatConfiguration? chatConfiguration, EvaluationResponseCacheProvider? responseCacheProvider, Iterable<String> ? cachingKeys, String? executionName, EvaluationMetricInterpretation? evaluationMetricInterpreter(EvaluationMetric)?, Iterable<String> ? tags}) - Creates a ReportingConfiguration.
Properties
-
cachingKeys
→ List<
String> -
Additional strings mixed into response cache keys.
final
- chatConfiguration → ChatConfiguration?
-
ChatClient configuration for AI-based evaluators.
final
- evaluationMetricInterpreter → EvaluationMetricInterpretation? Function(EvaluationMetric)?
-
Optional function that overrides EvaluationMetricInterpretations.
final
-
evaluators
→ List<
Evaluator> -
The evaluators invoked for each scenario run.
final
- executionName → String
-
Name for this evaluation batch execution.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- responseCacheProvider → EvaluationResponseCacheProvider?
-
Optional response cache provider.
final
- resultStore → EvaluationResultStore
-
Where ScenarioRunResults are persisted.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Labels applied to every ScenarioRun created from this configuration.
final
Methods
-
createScenarioRun(
String scenarioName, String iterationName, {CancellationToken? cancellationToken}) → Future< ScenarioRun> -
Creates a ScenarioRun for the given
scenarioNameanditerationName. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited