TextToSpeechOptions class
Options for text-to-speech requests.
This is an experimental feature.
- Annotations
-
- @Source(name: 'TextToSpeechOptions.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/TextToSpeech/')
Constructors
- TextToSpeechOptions({String? modelId, String? voiceId, String? language, String? audioFormat, double? speed, double? pitch, double? volume, Object? rawRepresentationFactory(TextToSpeechClient)?, AdditionalPropertiesDictionary? additionalProperties})
- Creates a new TextToSpeechOptions.
Properties
- additionalProperties ↔ AdditionalPropertiesDictionary?
-
Additional properties.
getter/setter pair
- audioFormat ↔ String?
-
The desired audio format (e.g.
"audio/mpeg","mp3","wav").getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- language ↔ String?
-
The BCP 47 language tag for generated speech (e.g.
"en-US").getter/setter pair - modelId ↔ String?
-
The model to use for synthesis.
getter/setter pair
- pitch ↔ double?
-
Speech pitch multiplier.
1.0is normal pitch.getter/setter pair - rawRepresentationFactory ↔ Object? Function(TextToSpeechClient)?
-
A callback that produces the implementation-specific options object.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed ↔ double?
-
Speech speed multiplier.
1.0is normal speed.getter/setter pair - voiceId ↔ String?
-
The voice identifier to use.
getter/setter pair
- volume ↔ double?
-
Speech volume multiplier.
1.0is normal volume.getter/setter pair
Methods
-
clone(
) → TextToSpeechOptions - Creates a shallow clone of this TextToSpeechOptions.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited