TextToSpeechResponseUpdate class
A single streaming response chunk from a TextToSpeechClient.
This is an experimental feature.
- Annotations
-
- @Source(name: 'TextToSpeechResponseUpdate.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/TextToSpeech/')
Constructors
- TextToSpeechResponseUpdate({DataContent? audio, String? responseId, String? modelId, Object? rawRepresentation, AdditionalPropertiesDictionary? additionalProperties})
- Creates a new TextToSpeechResponseUpdate.
Properties
- additionalProperties ↔ AdditionalPropertiesDictionary?
-
Additional properties.
getter/setter pair
- audio ↔ DataContent?
-
Partial audio data for this update.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- modelId ↔ String?
-
The model that produced this update.
getter/setter pair
- rawRepresentation ↔ Object?
-
The underlying implementation-specific object.
getter/setter pair
- responseId ↔ String?
-
The response ID shared across all updates for one request.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited