ToolApprovalResponseContent class
Represents a response to a ToolApprovalRequestContent, indicating whether the tool call was approved.
- Inheritance
-
- Object
- AIContent
- InputResponseContent
- ToolApprovalResponseContent
- Annotations
-
- @Source(name: 'ToolApprovalResponseContent.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Contents/')
Constructors
- ToolApprovalResponseContent({required String requestId, required bool approved, required ToolCallContent toolCall, String? reason, Object? rawRepresentation, AdditionalPropertiesDictionary? additionalProperties})
- Creates a new ToolApprovalResponseContent.
Properties
- additionalProperties ↔ AdditionalPropertiesDictionary?
-
Additional properties.
getter/setter pairinherited
- approved → bool
-
Whether the tool call was approved for execution.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rawRepresentation ↔ Object?
-
The underlying implementation-specific representation of this content.
getter/setter pairinherited
- reason ↔ String?
-
An optional reason for the approval or rejection.
getter/setter pair
- requestId → String
-
Unique identifier correlating this response with its request.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolCall → ToolCallContent
-
The tool call that was subject to approval.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited