extensions
library
Classes
AIAnnotation
Base class for annotations on AI content.
AIContent
Base class for all AI content types.
AIFunction
Represents a function that can be described to and invoked by an AI model.
AIFunctionArguments
Represents the arguments passed to an AI function invocation.
AIFunctionDeclaration
Represents a function that can be described to an AI service.
AIFunctionFactory
A factory for creating AIFunction instances from simple callbacks.
AIFunctionFactoryOptions
Options for controlling how AIFunctionFactory creates an AIFunction .
AITool
Base class for tools that can be provided to an AI model.
AndVectorStoreFilter
A filter that requires all filters to match.
AnnotatedRegion
Base class for annotated regions.
AnonymousDelegatingChatClient
A DelegatingChatClient that uses anonymous delegates to implement
its functionality.
AnyTagEqualToFilterClause
A filter clause that matches records where a collection field contains a
specific string value.
AnyTagEqualToVectorStoreFilter
A filter that matches records where a collection field contains a specific
string value.
ApplicationLifetime
Allows consumers to perform cleanup during a graceful shutdown.
ApprovalRequiredAIFunction
An AIFunction that is marked as requiring user approval before
invocation.
AsyncDisposable
Provides a mechanism for releasing unmanaged resources asynchronously.
AsyncServiceScope
A ServiceScope implementation that implements AsyncDisposable .
AutoChatToolMode
Indicates that a chat client is free to select any of the available tools,
or none at all.
BackgroundService
Base class for implementing a long running HostedService .
BLEUAlgorithm
Static helpers for computing BLEU scores.
BLEUEvaluator
Evaluates response quality using the BLEU (Bilingual Evaluation
Understudy) algorithm.
BLEUEvaluatorContext
Contextual information for BLEUEvaluator : one or more reference
responses to compare against.
BooleanMetric
An EvaluationMetric with a boolean value (pass/fail or yes/no).
BufferedLogger
Enables logging providers to handle batched log entries.
BufferedLogRecord
Represents a buffered log record to be written in batch to a buffered
logger.
BufferedLogRecordImpl
Default implementation of BufferedLogRecord .
CacheEntry
Represents an entry in the MemoryCache .
CachingChatClient
An abstract DelegatingChatClient that caches chat responses.
CallbackNode
All of the state associated a registered callback, in a node that's
part of a linked list of registered callbacks.
CancellationCallbackInfo
CancellationChangeToken
A ChangeToken implementation using CancellationToken .
CancellationToken
Propagates notification that operations should be canceled.
CancellationTokenRegistration
CancellationTokenSource
Signals to a CancellationToken that it should be canceled.
ChainedConfigurationProvider
Chained implementation of ConfigurationProvider .
ChainedConfigurationSource
Represents a chained Configuration as a ConfigurationSource .
ChangeToken
Propagates notifications that a change has occurred.
ChatClient
Represents a chat client.
ChatClientBuilder
Builds a pipeline of chat client middleware.
ChatClientMetadata
Provides metadata about a chat client.
ChatConfiguration
Specifies the ChatClient to use when evaluation is performed by an AI
model.
ChatDetails
Records details for all LLM chat turns in a ScenarioRun execution.
ChatFinishReason
Represents the reason a chat response finished being generated.
ChatMessage
Represents a chat message used by a chat client.
ChatOptions
Represents the options for a chat request.
ChatReducer
Reduces a list of chat messages (e.g. for context window
management).
ChatResponse
Represents the response to a chat request.
ChatResponseFormat
Represents the desired format of a chat response.
ChatResponseFormatJson
Requests structured JSON output without a specific schema.
ChatResponseFormatJsonSchema
Requests structured JSON output conforming to a specific schema.
ChatResponseFormatText
Requests unstructured text output.
ChatResponseUpdate
Represents a single streaming update to a chat response.
ChatRole
Represents the role of a chat message author.
ChatToolMode
Represents the mode in which tools are used by the chat client.
ChatTurnDetails
Details for a single LLM chat conversation turn in a ScenarioRun .
CitationAnnotation
An annotation citing a source.
CodeInterpreterToolCallContent
Represents a code interpreter tool call invoked by a hosted service.
CodeInterpreterToolResultContent
Represents the result of a code interpreter tool invocation by a hosted
service.
CodeVulnerabilityEvaluator
Evaluates AI responses for code vulnerabilities (e.g. injection flaws).
CoherenceEvaluator
Evaluates the coherence of an AI response — logical organization, flow,
and readability.
CollectionModel
Represents the runtime model for a vector store record type.
CollectionModelBuilder
Builds a CollectionModel from a VectorStoreCollectionDefinition .
CollectionModelBuildingOptions
Options that control how a CollectionModel is built.
CommandLineConfigurationProvider
A command line based ConfigurationProvider .
CommandLineConfigurationSource
Represents command line arguments as an ConfigurationSource .
CompletenessEvaluator
Evaluates how completely an AI response covers the key information in a
ground truth reference.
CompletenessEvaluatorContext
Context for CompletenessEvaluator : the ground truth response against
which completeness is measured.
CompositeChangeToken
An ChangeToken which represents one or more ChangeToken instances.
CompositeEvaluator
An Evaluator that composes multiple Evaluator s and runs them
concurrently.
CompositeFileProvider
Aggregates multiple file providers into a single provider.
ConfigurationBuilder
Used to build key/value based configuration settings for use in an
application.
ConfigurationBuilderProperties
ConfigurationChangeTokenSource <TOptions >
Creates ChangeToken s so that OptionsMonitor gets
notified when Configuration changes.
ConfigurationManager
ConfigurationManager is a mutable configuration object. It is both an
ConfigurationBuilder and an ConfigurationRoot . As sources are added, it
updates its current view of configuration.
ConfigurationPath
Utility methods and constants for manipulating Configuration paths
ConfigurationProvider
Provides configuration key/values for an application.
ConfigurationReloadToken
Implements ChangeToken .
ConfigurationRoot
Represents the root of an Configuration hierarchy.
ConfigurationSection
Represents a section of application configuration values.
ConfigurationSource
Represents a source of configuration key/values for an application.
ConfigurationSources
ConfigureNamedOptions <TOptions >
Represents something that configures the TOptions type.
ConfigureOptions <TOptions >
Represents something that configures the TOptions type.
Note: These are run before all PostConfigureOptions.
ConfigureOptionsChatClient
A delegating chat client that applies configuration to ChatOptions
before each request.
ConfigureOptionsEmbeddingGenerator
A delegating embedding generator that applies configuration to
EmbeddingGenerationOptions before each request.
ConfigureOptionsImageGenerator
A delegating image generator that applies configuration to
ImageGenerationOptions before each request.
ConfigureOptionsSpeechToTextClient
A delegating speech-to-text client that applies configuration to
SpeechToTextOptions before each request.
ConfigureOptionsTextToSpeechClient
A DelegatingTextToSpeechClient that applies a configuration callback to
TextToSpeechOptions before each request.
ConsoleFormatter
Allows custom log message formatting for console output.
ConsoleFormatterNames
Reserved formatter names for built-in console formatters.
ConsoleFormatterOptions
Base options class for console log formatters.
ConsoleLogger
A logger that writes messages to the console output.
ConsoleLoggerProvider
The provider for the ConsoleLogger .
ContentHarmEvaluator
Evaluates AI responses for all supported content harm categories:
hate/unfairness, violence, self-harm, and sexual content.
ContentSafetyEvaluator
Base class for evaluators that call the Azure AI Foundry Evaluation service
to detect unsafe content.
ContentSafetyServiceConfiguration
Configuration for connecting to the Azure AI Foundry Evaluation service.
CrossFileTestOverrides
Overrides some functions of CrossFile for testing purposes
DataContent
Represents binary data content, such as an image or audio.
DataPropertyModel
Represents a data property on a vector store record.
DebugLogger
A logger that writes messages in the debug output window only when a
debugger is attached.
DebugLoggerProvider
The provider for the DebugLogger .
DefaultHostApplicationBuilder
Represents a hosted applications and services builder that helps manage
configuration, logging, lifetime, and more.
DefaultHostBuilder
DefaultLoggerLevelConfigureOptions
DefaultServiceFactoryAdapter <TContainerBuilder >
DefaultServiceProviderFactory
Default implementation of ServiceProviderFactory<TContainerBuilder> .
DelegatingAIFunction
An AIFunction that delegates all calls to an inner function.
DelegatingAIFunctionDeclaration
An AIFunctionDeclaration that delegates its properties to an inner
declaration.
DelegatingChatClient
Provides an optional base class for an ChatClient that passes through
calls to another instance.
DelegatingEmbeddingGenerator
An EmbeddingGenerator that delegates all calls to an inner generator.
DelegatingHandler
Base class for composing HTTP handlers into a pipeline.
DelegatingHostedFileClient
A HostedFileClient that delegates all calls to an inner client.
DelegatingImageGenerator
An ImageGenerator that delegates all calls to an inner generator.
DelegatingSpeechToTextClient
A SpeechToTextClient that delegates all calls to an inner client.
DelegatingTextToSpeechClient
A TextToSpeechClient that delegates all calls to an inner client.
Directory
A reference to a directory on the file system.
DirectoryContents
Represents a directory's content in the file provider.
DirectoryInfoBase
Enumerates all files and directories in the directory.
DirectoryInfoWrapper
DiskBasedReportingConfiguration
Factory for a fully disk-backed ReportingConfiguration .
DiskBasedResponseCache
A ResponseCache that persists ChatResponse s as JSON files on disk.
DiskBasedResponseCacheProvider
An EvaluationResponseCacheProvider that stores response caches on disk.
DiskBasedResultStore
Stores ScenarioRunResult s as JSON files under storageRootPath.
Disposable
Provides a mechanism for releasing unmanaged resources.
DistanceFunction
Defines the distance functions that can be used to measure similarity
between vectors in a vector store.
DistributedCache
Represents a distributed cache of serialized values.
DistributedCacheEntryOptions
Provides options for configuring distributed cache entries.
Embedding
Represents a generated embedding vector.
EmbeddingGenerationDispatcher
Encapsulates runtime embedding generation dispatch for a specific
Embedding subtype.
EmbeddingGenerationOptions
Options for embedding generation requests.
EmbeddingGenerator
Represents an embedding generator.
EmbeddingGeneratorBuilder
Builds a pipeline of embedding generator middleware.
EmbeddingGeneratorMetadata
Provides metadata about an embedding generator.
Environments
Commonly used environment names.
EnvironmentVariablesConfigurationProvider
EnvironmentVariablesConfigurationSource
Represents environment variables as an ConfigurationSource .
EqualToFilterClause
A filter clause that matches records where a field equals a specific value.
EqualToVectorStoreFilter
A filter that matches records where a field equals a specific value.
EquivalenceEvaluator
Evaluates whether an AI response is semantically equivalent to a ground
truth reference.
EquivalenceEvaluatorContext
Context for EquivalenceEvaluator : the expected ground-truth response.
ErrorCodes
Operating system error codes.
ErrorContent
Represents error content in a chat response.
EvaluationContext
Base class for contextual information beyond the conversation history that
an Evaluator may need to accurately evaluate a response.
EvaluationDiagnostic
A diagnostic message associated with an EvaluationMetric .
EvaluationMetric
Base class for all evaluation metric results.
EvaluationMetricInterpretation
Specifies how an EvaluationMetric 's result should be interpreted.
EvaluationResponseCacheProvider
Provides ResponseCache instances scoped to a particular scenario run.
EvaluationResult
A collection of EvaluationMetric s representing the result of an
evaluation run.
EvaluationResultStore
Stores and retrieves ScenarioRunResult s from a backing store.
Evaluator
Evaluates AI model responses and returns EvaluationResult s.
EventId
Identifies a logging event.
F1Algorithm
Computes word-overlap F1 scores.
F1Evaluator
Evaluates response quality using F1 scoring (shared word ratio).
F1EvaluatorContext
Contextual information for F1Evaluator : a single ground-truth reference
response.
File
A reference to a file on the file system.
FileInfo
FileInfoBase
Represents a file
FileInfoWrapper
FileLock
Type of lock when requesting a lock on a file.
FileMode
The modes in which a File can be opened.
FilePatternMatch
Represents a file that was matched by searching using a globbing pattern
FileProvider
A read-only file provider abstraction.
FileStat
The result of calling the POSIX stat() function on a file system object.
FileSystem
A generic representation of a file system.
FileSystemEntity
The common super class for io.File , io.Directory , and io.Link objects.
FileSystemEntityType
The type of an entity on the file system,
such as a file, directory, or link.
FileSystemEvent
Base event class emitted by FileSystemEntity.watch .
FileSystemInfoBase
Shared abstraction for files and directories
FilterClause
Base class for filter clauses used when querying a vector store.
FilteredRecordRetrievalOptions <TRecord >
Options for retrieving records from a vector store collection with optional
filtering and ordering.
FluencyEvaluator
Evaluates the fluency of an AI response — grammar, vocabulary, and
clarity of written communication.
FormattedConsoleLogger
A logger that writes formatted messages to the console output.
FormattedConsoleLoggerProvider
Provider for FormattedConsoleLogger instances.
ForwardingFileSystem
A file system that forwards all methods and properties to a delegate.
ForwardingFileSystemEntity <T extends FileSystemEntity , D extends FileSystemEntity >
A file system entity that forwards all methods and properties to a delegate.
FunctionCallContent
Represents a request from the model to invoke a function.
FunctionInvocationContext
Provides context for a function invocation within a chat client pipeline.
FunctionInvocationResult
The result of a function invocation.
FunctionInvokingChatClient
A delegating chat client that automatically invokes functions
requested by the model.
FunctionResultContent
Represents the result of a function call.
GeneratedEmbeddings
Represents a collection of generated embeddings.
GLEUAlgorithm
Computes Google-BLEU (GLEU) scores.
GLEUEvaluator
Evaluates response quality using Google-BLEU (GLEU) n-gram overlap.
GLEUEvaluatorContext
Contextual information for GLEUEvaluator : one or more reference
responses to compare against.
Glob
A glob for matching and listing files and directories.
GroundednessEvaluator
Evaluates how well an AI response is grounded in provided context,
without introducing unsupported information.
GroundednessEvaluatorContext
Context for GroundednessEvaluator : the grounding information against
which fidelity is measured.
GroundednessProEvaluator
Enterprise-grade groundedness evaluator using the Azure AI Foundry service.
GroundednessProEvaluatorContext
Context for GroundednessProEvaluator : the grounding information against
which response fidelity is assessed.
HateAndUnfairnessEvaluator
Evaluates AI responses for hate speech and unfairness.
Host
A program abstraction.
HostApplicationBuilder
Represents a hosted applications and services builder which helps manage
configuration, logging, lifetime, and more.
HostApplicationBuilderSettings
Settings for constructing an HostApplicationBuilder .
HostApplicationLifetime
Allows consumers to be notified of application lifetime events.
This interface is not intended to be user-replaceable.
HostBuilder
A program initialization abstraction.
HostBuilderAdapter
HostBuilderContext
Context containing the common services on the Host . Some
properties may be null until set by the Host .
HostDefaults
Constants for HostBuilder configuration keys.
HostedCodeInterpreterTool
A tool representing a hosted code interpreter capability.
HostedFileClient
A client for uploading, downloading, and managing files hosted by an AI
service.
HostedFileClientBuilder
Builds a pipeline of HostedFileClient middleware.
HostedFileClientMetadata
Provides metadata about a HostedFileClient .
HostedFileClientOptions
Options for HostedFileClient requests.
HostedFileContent
Represents a reference to a file hosted by the AI service.
HostedFileSearchTool
A tool representing a hosted file search capability.
HostedImageGenerationTool
A tool representing a hosted image generation capability.
HostedMcpServerTool
A tool representing a hosted MCP server.
HostedMcpServerToolAlwaysRequireApprovalMode
Always require approval for MCP server tool calls.
HostedMcpServerToolApprovalMode
Approval mode for hosted MCP server tools.
HostedMcpServerToolNeverRequireApprovalMode
Never require approval for MCP server tool calls.
HostedMcpServerToolRequireSpecificApprovalMode
Require approval for specific MCP server tool calls.
HostedService
Defines methods for objects that are managed by the host.
HostedToolSearchTool
A marker tool that enables on-demand tool discovery from a hosted service.
HostedVectorStoreContent
Represents a reference to a vector store hosted by the AI service.
HostedWebSearchTool
A tool representing a hosted web search capability.
HostEnvironment
Provides information about the hosting environment an application is
running in.
HostingEnvironment
HostLifetime
Tracks host lifetime.
HttpClientAsyncLogger
An abstraction for asyncronous custom HTTP request logging for a
named HttpClient instances returned by HttpClientFactory .
HttpClientBuilder
Fluent builder used to configure named HTTP clients.
HttpClientFactory
A factory abstraction for a component that can create http.BaseClient
instances with custom configuration for a given logical name.
HttpClientFactoryOptions
Options used by the default HTTP client factory.
HttpClientLogger
An abstraction for custom HTTP request logging for a named HttpClient
instances returned by HttpClientFactory .
HttpClientLoggerHandler
HttpMessageHandler
HttpMessageHandlerBuilder
HttpMessageHandlerBuilderFilter
Used by the DefaultHttpClientFactory to apply additional configuration
to the HttpMessageHandlerBuilder immediately before calling build.
HttpMessageHandlerFactory
HybridSearchOptions <TRecord >
Options for a hybrid vector-and-keyword search.
IConfiguration
Represents a set of key/value application configuration properties.
IConfigurationSection
Represents a section of application configuration values.
IKeywordHybridSearchable <TRecord >
Provides hybrid vector-and-keyword search over a collection of records.
ImageGeneratingChatClient
A DelegatingChatClient that handles image generation tool calls
by delegating to an ImageGenerator .
ImageGenerationOptions
Options for image generation requests.
ImageGenerationRequest
Represents an image generation request.
ImageGenerationResponse
Represents an image generation response.
ImageGenerationToolCallContent
Represents an image generation tool call invoked by a hosted service.
ImageGenerationToolResultContent
Represents the result of an image generation tool invocation by a hosted
service.
ImageGenerator
Represents an image generator.
ImageGeneratorBuilder
Builds a pipeline of image generator middleware.
ImageGeneratorMetadata
Provides metadata about an image generator.
IndexKind
Defines the types of index that can be used to index vector data.
IndirectAttackEvaluator
Evaluates AI responses for indirect prompt injection attacks.
IniConfigurationParser
Parses INI configuration data into key-value pairs.
IniConfigurationProvider
An INI based ConfigurationProvider .
IniConfigurationSource
Represents an INI configuration string as a ConfigurationSource .
IniStreamConfigurationProvider
INI configuration provider that reads from a stream.
IniStreamConfigurationSource
Represents an INI stream as a ConfigurationSource .
InMemoryDirectoryInfo
Represents an in-memory directory for pattern matching without
accessing the file system.
InMemoryFileInfo
Represents an in-memory file for pattern matching.
InputRequestContent
Represents a request for input from the user or application.
InputResponseContent
Represents the response to an InputRequestContent .
InstrumentRule
Contains a set of parameters used to determine which instruments are
enabled for which listeners. Unspecified parameters match anything.
IntentResolutionEvaluator
Evaluates how effectively an AI system identifies and resolves user intent.
IntentResolutionEvaluatorContext
Context for IntentResolutionEvaluator : the tool definitions used when
generating the response.
IOSink
A combined byte and text output.
IVectorSearchable <TRecord >
Provides vector similarity search over a collection of records.
JsonConfigurationParser
JsonConfigurationProvider
A JSON based ConfigurationProvider .
JsonConfigurationSource
JsonConsoleFormatter
A console formatter that formats log messages as JSON.
JsonConsoleFormatterOptions
Options for the built-in JSON console log formatter.
KeyPropertyModel
Represents a key property on a vector store record.
LifetimeTrackingHttpMessageHandler
A delegating handler that tracks the lifetime of HTTP message handlers
and prevents premature disposal.
Link
A reference to a symbolic link on the file system.
LinkedNCancellationTokenSource
ListenerSubscription
LogDefineOptions
Options for configuring logger message delegates.
LogEntry <TState >
Holds information about a log entry.
Logger
Represents a type used to perform logging.
LoggerFactory
Represents a type used to configure the logging system and
create instances of Logger from the registered LoggerProvider s.
LoggerFactoryOptions
The options for a LoggerFactory .
LoggerFilterOptions
The options for a LoggerFilter.
LoggerFilterRule
Defines a rule used to filter log messages.
LoggerMessage
Creates delegates for logging that can be cached and reused for improved
performance.
LoggerProvider
Represents a type that can create instances of Logger .
LoggerProviderConfiguration <T >
Provides configuration for a specific logger provider type.
LoggerProviderConfigurationFactory
Factory to provide configuration for logger providers.
LoggerProviderConfigurationFactoryImpl
Factory implementation for providing configuration to logger providers.
LoggerProviderConfigurationImpl <T >
Implementation of ILoggerProviderConfiguration that retrieves
configuration for a specific logger provider type.
LoggingBuilder
An interface for configuring logging providers.
LoggingChatClient
A delegating chat client that logs chat operations to an Logger .
LoggingConfiguration
Loads logging configuration from Configuration .
LoggingEmbeddingGenerator
A delegating embedding generator that logs operations to a Logger .
LoggingHostedFileClient
A DelegatingHostedFileClient that logs file operations.
LoggingHttpMessageHandler
Handles logging of the lifecycle for an HTTP request.
LoggingHttpMessageHandlerBuilderFilter
A filter that adds a LoggingHttpMessageHandler to the HTTP client
pipeline for all named clients.
LoggingImageGenerator
A delegating image generator that logs operations to a Logger .
LoggingScopeHttpMessageHandler
A delegating handler that establishes a logging scope for each HTTP request.
LoggingSpeechToTextClient
A delegating speech-to-text client that logs operations to a Logger .
LoggingTextToSpeechClient
A DelegatingTextToSpeechClient that logs requests and responses.
Matcher
Searches the file system for files with names that match specified patterns.
McpServerToolCallContent
Represents a tool call request to an MCP server by a hosted service.
MCPServerToolResultContent
Represents the result of an MCP server tool call by a hosted service.
MeasurementHandlers
A set of supported measurement types. If a listener does not support
a given type, the measurement will be skipped.
MemoryCache
Represents a local in-memory cache whose values are not serialized.
MemoryCacheEntryOptions
Provides options for configuring memory cache entries.
MemoryCacheImpl
Implementation of MemoryCache .
MemoryCacheOptions
Provides configuration options for MemoryCacheImpl .
MemoryCacheStatistics
Holds statistics for the memory cache.
MemoryConfigurationProvider
In-memory implementation of ConfigurationProvider
MemoryConfigurationSource
Represents in-memory data as an ConfigurationSource .
MemoryDistributedCache
An implementation of DistributedCache using an in-memory cache.
MessageCountingChatReducer
A chat reducer that keeps the most recent messages up to a target count.
MetricsBuilder
Represents a type used to configure the metrics system by registering
MetricsListener s and using rules to determine which metrics are enabled.
MetricsListener
Represents a type used to listen to metrics emitted from the system.
MetricsSubscriptionManager
NGram <T >
An n-gram: a contiguous sequence of n tokens.
NoneChatToolMode
No tools should be used by the model.
NotFoundDirectoryContents
Represents a non-existing directory
NotFoundFileInfo
Represents a non-existing file.
NullChangeToken
An empty change token that doesn't raise any change callbacks.
NullFileProvider
An empty file provider with no contents.
NullLogger
Minimalistic logger that does nothing.
NullLoggerFactory
An LoggerFactory used to create instance of
NullLogger that logs nothing.
NullScope
An empty scope without any logic.
NullTypedLogger <T >
Generic null logger that does nothing.
NumericMetric
An EvaluationMetric with a numeric value.
ObservableInstrumentsSource
An interface registered with each MetricsListener using
MetricsListener.initialize(ObservableInstrumentsSource) . The listener
can call recordObservableInstruments to receive the current set of
measurements for enabled observable instruments.
OpenAIChatClient
An ChatClient for the OpenAI chat completions API.
OpenAIClientOptions
Configuration options for an OpenAI-compatible API client.
OpenAIEmbeddingGenerator
An EmbeddingGenerator for the OpenAI embeddings API.
OpenAIImageGenerator
An ImageGenerator for the OpenAI image generation API.
OpenAISpeechToTextClient
An SpeechToTextClient for the OpenAI audio transcription API.
OpenAITextToSpeechClient
An TextToSpeechClient for the OpenAI audio speech API.
OpenTelemetryChatClient
A DelegatingChatClient that records OpenTelemetry spans for each request.
OpenTelemetryConsts
Semantic convention constants for AI telemetry spans and attributes.
OpenTelemetryEmbeddingGenerator
A DelegatingEmbeddingGenerator that records OpenTelemetry spans.
OpenTelemetryImageGenerator
A DelegatingImageGenerator that records OpenTelemetry spans.
OpenTelemetryTextToSpeechClient
A DelegatingTextToSpeechClient that records OpenTelemetry spans.
Options <TOptions >
Used to retrieve configured TOptions instances.
OptionsChangeTokenSource <TOptions >
Used to fetch ChangeToken used for tracking options changes.
OptionsFactory <TOptions >
Used to create TOptions instances.
OptionsMonitor <TOptions >
Used for notifications when TOptions instances change.
OptionsMonitorCache <TOptions >
Used by OptionsMonitor to cache TOptions instances.
OptionsSnapshot <TOptions >
Used to access the value of TOptions for the lifetime of a request.
OrderByClause
A clause that defines a single ordering direction for a field.
OrVectorStoreFilter
A filter that requires at least one of filters to match.
PatternMatchingResult
Represents a collection of FilePatternMatch
PhysicalDirectoryContents
Represents the contents of a physical file directory
PhysicalDirectoryInfo
Represents a directory on a physical filesystem
PhysicalFileInfo
Represents a file on a physical filesystem
PhysicalFileProvider
Looks up files using the on-disk file system.
PhysicalFileProviderOptions
Options for a PhysicalFileProvider .
PhysicalFilesWatcher
A file watcher that watches a physical filesystem for changes.
PollingFileChangeToken
A change token that polls for file changes.
PollingWildcardChangeToken
A change token that polls for file changes matching a wildcard pattern.
PostConfigureOptions <TOptions >
Represents something that configures the TOptions type.
PostEvictionCallbackRegistration
Registration for a callback that should be called when a cache entry
is evicted.
PropertyModel
Represents a property on a vector store record.
ProtectedMaterialEvaluator
Evaluates AI responses for copyrighted or otherwise protected material.
ProviderAliasUtilities
Utilities for working with logger provider aliases.
QualityEvaluatorBase
Shared evaluation loop for AI-based quality evaluators (1–5 scale).
RandomAccessFile
Random access to the data in a file.
ReasoningOptions
Options for configuring reasoning behavior in chat requests.
RecordRetrievalOptions
Options for retrieving records from a vector store collection by key.
ReducingChatClient
A DelegatingChatClient that reduces chat messages before forwarding
requests to the inner client.
Registrations
Set of all the registrations in the token source.
RelevanceEvaluator
Evaluates how well an AI response addresses the user's question.
RelevanceTruthAndCompletenessEvaluator
Evaluates an AI response on three dimensions — Relevance, Truth, and
Completeness — in a single model call, returning one NumericMetric per
dimension (each scored 1–5).
RelevanceTruthAndCompletenessRating
The structured JSON response from RelevanceTruthAndCompletenessEvaluator .
ReportingConfiguration
Bundles all configuration needed to create ScenarioRun instances for an
evaluation batch.
RequiredChatToolMode
The model must call at least one tool.
ResponseCache
A key-value cache for ChatResponse s used during evaluation.
ResponseCachingChatClient
A CachingChatClient that persists responses to a ResponseCache and
records per-turn latency and usage in a ChatDetails object.
ResponseContinuationToken
Represents a token that can be used to resume an interrupted response.
RetrievalEvaluator
Evaluates how well the retrieved context chunks are relevant to the user
request and ranked appropriately.
RetrievalEvaluatorContext
Context for RetrievalEvaluator : the retrieved context chunks to assess.
ScenarioRun
Orchestrates the evaluation of a single iteration of a scenario.
ScenarioRunResult
The persisted result of a single ScenarioRun evaluation.
Scope
SelfHarmEvaluator
Evaluates AI responses for self-harm advocacy.
ServiceCollection
Specifies the contract for a collection of service descriptors.
ServiceDescriptor
Describes a service with its service type, implementation, and lifetime.
ServiceFactoryAdapter
ServiceProvider
Defines a mechanism for retrieving a service object; that is, an object
that provides custom support to other objects.
ServiceProviderFactory <TContainerBuilder >
Provides an extension point for creating a container
specific builder and a ServiceProvider .
ServiceProviderIsKeyedService
Optional service used to determine if the specified type with the
specified service key is available from the ServiceProvider .
ServiceProviderIsService
Optional service used to determine if the specified type is available from
the ServiceProvider .
ServiceProviderOptions
Options for configuring various behaviors of the default
ServiceProvider implementation.
ServiceScope
The dispose() method ends the scope lifetime. Once dispose
is called, any scoped services that have been resolved from
ServiceProvider will be disposed.
ServiceScopeFactory
A factory for creating instances of ServiceScope ,
which is used to create services within a scope.
SexualEvaluator
Evaluates AI responses for sexual content.
SimpleConsoleFormatter
A simple console formatter that formats log messages with timestamps,
log levels, categories, and exception details.
SimpleConsoleFormatterOptions
Options for the built-in simple console log formatter.
SimpleWordTokenizer
Tokenizes text using rules inspired by the NLTK word tokenizer.
SpeechToTextClient
Represents a speech-to-text client.
SpeechToTextClientBuilder
Builds a pipeline of speech-to-text client middleware.
SpeechToTextClientMetadata
Provides metadata about a speech-to-text client.
SpeechToTextOptions
Options for speech-to-text requests.
SpeechToTextResponse
Represents a speech-to-text response.
SpeechToTextResponseUpdate
Represents a streaming update from a speech-to-text operation.
SpeechToTextResponseUpdateKind
The kind of a speech-to-text response update.
StaticFilterOptionsMonitor
StreamConfigurationProvider
Stream based configuration provider
StreamConfigurationSource
Stream based ConfigurationSource .
StringMetric
An EvaluationMetric with a string value.
SummarizingChatReducer
A ChatReducer that summarizes older messages using a ChatClient .
SupportRequiredService
Optional contract used by
ServiceProviderServiceExtensions.getRequiredService() to resolve services
if supported by ServiceProvider .
SystemdConsoleFormatter
A console formatter that formats log messages for systemd journal.
SystemdConsoleFormatterOptions
Options for the built-in systemd console log formatter.
TaskAdherenceEvaluator
Evaluates how accurately an AI system adhered to its assigned task,
instructions, and any tool use.
TaskAdherenceEvaluatorContext
Context for TaskAdherenceEvaluator : the tool definitions used when
generating the response.
Test
TextContent
Represents text content in a chat message.
TextReasoningContent
Represents reasoning or "thinking" content from an AI model.
TextSpanAnnotatedRegion
An annotated region defined by character span indices.
TextToSpeechClient
Represents a text-to-speech client.
TextToSpeechClientBuilder
Builds a pipeline of text-to-speech client middleware.
TextToSpeechClientMetadata
Provides metadata about a TextToSpeechClient .
TextToSpeechOptions
Options for text-to-speech requests.
TextToSpeechResponse
The result of a text-to-speech request.
TextToSpeechResponseUpdate
A single streaming response chunk from a TextToSpeechClient .
ToolApprovalRequestContent
Represents a request for approval before a tool call is executed.
ToolApprovalResponseContent
Represents a response to a ToolApprovalRequestContent , indicating
whether the tool call was approved.
ToolCallAccuracyEvaluator
Evaluates how accurately an AI system used the tools available to it,
examining relevance, parameter correctness, and value extraction accuracy.
ToolCallAccuracyEvaluatorContext
Context for ToolCallAccuracyEvaluator : the tool definitions used when
generating the response.
ToolCallContent
Base class for content types that represent a tool call request.
ToolReductionStrategy
Represents a strategy capable of selecting a reduced set of tools for a
chat request.
ToolResultContent
Base class for content types that represent the result of a tool call.
TypedLogger <T >
A generic logger interface used to enable activation of a named logger from
dependency injection.
TypedLoggerImpl <T >
Implementation of TypedLogger that wraps an underlying logger instance.
UngroundedAttributesEvaluator
Evaluates AI responses for ungrounded protected-class attributes or
emotional state inferences.
UngroundedAttributesEvaluatorContext
Context for UngroundedAttributesEvaluator : the grounding information
used to assess whether the response contains ungrounded attributes.
UriContent
Represents content referenced by a URI.
UsageContent
Content representing usage information.
UsageDetails
Provides usage details about a request/response.
ValidateOptions <TOptions >
Interface used to validate options.
ValidateOptions0 <TOptions >
Implementation of ValidateOptions<TOptions>
ValidateOptions1 <TOptions , TDep >
ValidateOptions2 <TOptions , TDep1 , TDep2 >
ValidateOptions3 <TOptions , TDep1 , TDep2 , TDep3 >
ValidateOptions4 <TOptions , TDep1 , TDep2 , TDep3 , TDep4 >
ValidateOptions5 <TOptions , TDep1 , TDep2 , TDep3 , TDep4 , TDep5 >
ValidateOptionsResult
Represents the result of an options validation.
ValidationResult
VectorDataStrings
Error message factory for vector store provider implementations.
VectorPropertyModel
Represents a vector property on a vector store record.
VectorSearchOptions <TRecord >
Options for a vector similarity search.
VectorSearchResult <TRecord >
Represents a single result from a vector similarity search.
VectorStore
Represents a vector store that holds collections of records.
VectorStoreCollection <TKey , TRecord >
Represents a collection of records in a vector store.
VectorStoreCollectionDefinition
Defines the schema of a vector store collection.
VectorStoreCollectionMetadata
Metadata about a vector store collection.
VectorStoreCollectionOptions
Base options for configuring a VectorStoreCollection .
VectorStoreDataAttribute
Marks a property on a record as a data field in a vector store collection.
VectorStoreDataProperty
Defines a data property in a vector store record.
VectorStoreFilter
Represents a filter to apply when querying a vector store collection.
VectorStoreKeyAttribute
Marks a property on a record as the key field in a vector store collection.
VectorStoreKeyProperty
Defines a key property in a vector store record.
VectorStoreMetadata
Metadata about a vector store instance.
VectorStoreProperty
Base class for all vector store record property definitions.
VectorStoreVectorAttribute
Marks a property on a record as a vector field in a vector store collection.
VectorStoreVectorProperty
Defines a vector property in a vector store record.
ViolenceEvaluator
Evaluates AI responses for violent content.
WebSearchToolCallContent
Represents a web search tool call invoked by a hosted service.
WebSearchToolResultContent
Represents the result of a web search tool invocation by a hosted service.
XFile
A CrossFile is a cross-platform, simplified File abstraction.
XFileInfo
Represents a file using cross_file's XFile for cross-platform support.
XmlConfigurationParser
Parses XML configuration data into key-value pairs.
XmlConfigurationProvider
An XML based ConfigurationProvider .
XmlConfigurationSource
Represents an XML configuration string as a ConfigurationSource .
XmlStreamConfigurationProvider
XML configuration provider that reads from a stream.
XmlStreamConfigurationSource
Represents an XML stream as a ConfigurationSource .
Typedefs
AdditionalPropertiesDictionary
= Map <String , Object ? >
A dictionary of additional properties.
CallbackRegistration
= void Function(Object ? state )
CancellationCallback
= void Function(Object ? state )
CategoryLevelFilterAction
= bool Function(String ? category , LogLevel level )
ChangeCallback
= void Function(Object ? state )
Callback signature for change notifications.
ChangeTokenConsumer
= void Function()
Action called when the token changes.
ChangeTokenProducer
= ChangeToken ? Function()
Produces the change token.
ChangeTokenTypedConsumer <TState >
= void Function(TState? state )
Action called when the token changes with state.
ChatClientFactory
= ChatClient Function(ChatClient innerClient )
A factory that creates middleware by wrapping an inner ChatClient .
ChatClientFactoryWithServices
= ChatClient Function(ChatClient innerClient , ServiceProvider services )
A factory that creates middleware by wrapping an inner ChatClient and
receiving the active ServiceProvider .
ChatClientResponseHandler
= Future <ChatResponse > Function(Iterable <ChatMessage > messages , ChatOptions ? options , ChatClient innerClient , CancellationToken ? cancellationToken )
A function that handles a chat response request.
ChatClientSharedDelegate
= Future <void > Function(Iterable <ChatMessage > messages , ChatOptions ? options , Future <void > next (Iterable <ChatMessage > messages , ChatOptions ? options , CancellationToken ? cancellationToken ), CancellationToken ? cancellationToken )
Delegate used to wrap both non-streaming and streaming operations.
ChatClientStreamingResponseHandler
= Stream <ChatResponseUpdate > Function(Iterable <ChatMessage > messages , ChatOptions ? options , ChatClient innerClient , CancellationToken ? cancellationToken )
A function that handles a streaming chat response request.
Configuration
= IConfiguration
Alias for IConfiguration for backwards compatibility.
ConfigureAppConfigurationDelegate
= void Function(HostBuilderContext context , ConfigurationBuilder configuration )
ConfigureContainer <TContainerBuilder >
= void Function(TContainerBuilder containerBuilder )
ConfigureContainerBuilder <TContainerBuilder >
= void Function(TContainerBuilder containerBuilder )
ConfigureContainerDelegate <TContainerBuilder >
= TContainerBuilder Function(HostBuilderContext context , TContainerBuilder builder )
ConfigureDefaultServiceProvider
= void Function(HostBuilderContext context , ServiceProviderOptions options )
ConfigureFilter
= bool Function(String name , String category , LogLevel level )
ConfigureFunctionInvokingChatClient
= void Function(FunctionInvokingChatClient client )
ConfigureHostConfigurationDelegate
= void Function(ConfigurationBuilder configuration )
ConfigureLoggerFactoryOptions
= void Function(LoggerFactoryOptions options )
ConfigureLoggingBuilder
= void Function(LoggingBuilder builder )
ConfigureLoggingChatClient
= void Function(LoggingChatClient client )
ConfigureOptionsAction1
= void Function(LoggerFilterOptions options )
ConfigureServicesDelegate
= void Function(HostBuilderContext context , ServiceCollection services )
ContextResolver
= HostBuilderContext ? Function()
CreateServiceProvider
= ServiceProvider Function()
FactoryResolver <TContainerBuilder >
= ServiceProviderFactory <TContainerBuilder > Function(HostBuilderContext hostContext )
FilterAction
= bool Function(String provider , String category , LogLevel level )
HttpClientAction
= void Function(BaseClient client , ServiceProvider services )
HttpMessageHandlerBuilderAction
= void Function(HttpMessageHandlerBuilder builder , ServiceProvider services )
ImplementationFactory
= Object Function(ServiceProvider services )
A factory to create new instances of the service implementation.
InnerClientFactory
= ChatClient Function(ServiceProvider services )
InnerEmbeddingGeneratorFactory
= EmbeddingGenerator Function(ServiceProvider services )
A factory that creates an EmbeddingGenerator from a ServiceProvider .
InnerHostedFileClientFactory
= HostedFileClient Function(ServiceProvider services )
A factory that creates a HostedFileClient from a ServiceProvider .
InnerImageGeneratorFactory
= ImageGenerator Function(ServiceProvider services )
A factory that creates an ImageGenerator from a ServiceProvider .
InnerSpeechToTextClientFactory
= SpeechToTextClient Function(ServiceProvider services )
A factory that creates a SpeechToTextClient from a ServiceProvider .
InnerTextToSpeechClientFactory
= TextToSpeechClient Function(ServiceProvider services )
A factory that creates a TextToSpeechClient from a ServiceProvider .
KeyedImplementationFactory
= Object Function(ServiceProvider services , Object ? serviceKey )
LevelFilterAction
= bool Function(LogLevel level )
LogFormatter <TState >
= String Function(TState state , Object ? error )
Function to create a String message of the state and exception.
MeasurementCallback <TValue >
= void Function(Instrument instrument , TValue measurement , Map <String , Object ? > tags , Object ? state )
A callback to represent the MeterListener callbacks used in
measurements recording operation.
PostEvictionDelegate
= void Function(Object key , Object ? value , EvictionReason reason , Object ? state )
Signature for callbacks that are called when a cache entry is evicted.
ServiceProviderFactoryDelegate <TContainerBuilder >
= ServiceProviderFactory <TContainerBuilder > Function(HostBuilderContext ? context )
Task
= Future <void >
TimerCallback
= void Function(Object ? state )
TypedImplementationFactory <T >
= T Function(ServiceProvider services )
TypedKeyedImplementationFactory <T >
= T Function(ServiceProvider services , Object ? serviceKey )
ValidationCallback0 <TOptions >
= bool Function(TOptions options )
ValidationCallback1 <TOptions , TDep >
= bool Function(TOptions options , TDep dependency )
ValidationCallback2 <TOptions , TDep1 , TDep2 >
= bool Function(TOptions options , TDep1 dependency1 , TDep2 dependency2 )
ValidationCallback3 <TOptions , TDep1 , TDep2 , TDep3 >
= bool Function(TOptions options , TDep1 dependency1 , TDep2 dependency2 , TDep3 dependency3 )
ValidationCallback4 <TOptions , TDep1 , TDep2 , TDep3 , TDep4 >
= bool Function(TOptions options , TDep1 dependency1 , TDep2 dependency2 , TDep3 dependency3 , TDep4 dependency4 )
ValidationCallback5 <TOptions , TDep1 , TDep2 , TDep3 , TDep4 , TDep5 >
= bool Function(TOptions options , TDep1 dependency1 , TDep2 dependency2 , TDep3 dependency3 , TDep4 dependency4 , TDep5 dependency5 )
VoidCallback
= void Function()
Exceptions / Errors
AggregateException
Represents one or more errors that occur during application execution.
ArgumentException
The exception that is thrown when one of the arguments provided
to a method is not valid.
ArgumentNullException
An exception that is thrown when a method is invoked and at least
one of the passed arguments is null but should never be null.
FileNotFoundException
FileSystemException
Exception thrown when a file operation fails.
IOException
Base class for all IO related exceptions.
ObjectDisposedException
/// The exception that is thrown when accessing an object that was disposed.
OperationCanceledException
The exception that is thrown in a thread upon cancellation of
an operation that the thread was executing.
OSError
An Exception holding information about an error from the
operating system.
SystemException
This class is provided as a means to differentiate between system
exceptions and application exceptions.
VectorStoreException
Represents an error that occurred while interacting with a vector store.