extensions library

Classes

ApplicationLifetime
Allows consumers to perform cleanup during a graceful shutdown.
AsyncDisposable
Provides a mechanism for releasing unmanaged resources asynchronously.
AsyncServiceScope
A ServiceScope implementation that implements AsyncDisposable.
BackgroundService
Base class for implementing a long running HostedService.
BufferedLogger
Enables logging providers to handle batched log entries.
BufferedLogRecord
Represents a buffered log record to be written in batch to a buffered logger.
BufferedLogRecordImpl
Default implementation of BufferedLogRecord.
CacheEntry
Represents an entry in the MemoryCache.
CallbackNode
All of the state associated a registered callback, in a node that's part of a linked list of registered callbacks.
CancellationCallbackInfo
CancellationChangeToken
A ChangeToken implementation using CancellationToken.
CancellationToken
Propagates notification that operations should be canceled.
CancellationTokenRegistration
CancellationTokenSource
Signals to a CancellationToken that it should be canceled.
ChainedConfigurationProvider
Chained implementation of ConfigurationProvider.
ChainedConfigurationSource
Represents a chained Configuration as a ConfigurationSource.
ChangeToken
Propagates notifications that a change has occurred.
CommandLineConfigurationProvider
A command line based ConfigurationProvider.
CommandLineConfigurationSource
Represents command line arguments as an ConfigurationSource.
CompositeChangeToken
An ChangeToken which represents one or more ChangeToken instances.
CompositeFileProvider
Aggregates multiple file providers into a single provider.
ConfigurationBuilder
Used to build key/value based configuration settings for use in an application.
ConfigurationBuilderProperties
ConfigurationChangeTokenSource<TOptions>
Creates ChangeTokens so that OptionsMonitor gets notified when Configuration changes.
ConfigurationManager
ConfigurationManager is a mutable configuration object. It is both an ConfigurationBuilder and an ConfigurationRoot. As sources are added, it updates its current view of configuration.
ConfigurationPath
Utility methods and constants for manipulating Configuration paths
ConfigurationProvider
Provides configuration key/values for an application.
ConfigurationReloadToken
Implements ChangeToken.
ConfigurationRoot
Represents the root of an Configuration hierarchy.
ConfigurationSection
Represents a section of application configuration values.
ConfigurationSource
Represents a source of configuration key/values for an application.
ConfigurationSources
ConfigureNamedOptions<TOptions>
Represents something that configures the TOptions type.
ConfigureOptions<TOptions>
Represents something that configures the TOptions type. Note: These are run before all PostConfigureOptions.
ConsoleFormatter
Allows custom log message formatting for console output.
ConsoleFormatterNames
Reserved formatter names for built-in console formatters.
ConsoleFormatterOptions
Base options class for console log formatters.
ConsoleLogger
A logger that writes messages to the console output.
ConsoleLoggerProvider
The provider for the ConsoleLogger.
CrossFileTestOverrides
Overrides some functions of CrossFile for testing purposes
DebugLogger
A logger that writes messages in the debug output window only when a debugger is attached.
DebugLoggerProvider
The provider for the DebugLogger.
DefaultHostApplicationBuilder
Represents a hosted applications and services builder that helps manage configuration, logging, lifetime, and more.
DefaultHostBuilder
DefaultLoggerLevelConfigureOptions
DefaultServiceFactoryAdapter<TContainerBuilder>
DefaultServiceProviderFactory
Default implementation of ServiceProviderFactory<TContainerBuilder>.
DelegatingHandler
Base class for composing HTTP handlers into a pipeline.
Directory
A reference to a directory on the file system.
DirectoryContents
Represents a directory's content in the file provider.
DirectoryInfoBase
Enumerates all files and directories in the directory.
DirectoryInfoWrapper
Disposable
Provides a mechanism for releasing unmanaged resources.
DistributedCache
Represents a distributed cache of serialized values.
DistributedCacheEntryOptions
Provides options for configuring distributed cache entries.
Environments
Commonly used environment names.
EnvironmentVariablesConfigurationProvider
EnvironmentVariablesConfigurationSource
Represents environment variables as an ConfigurationSource.
ErrorCodes
Operating system error codes.
EventId
Identifies a logging event.
File
A reference to a file on the file system.
FileInfo
FileInfoBase
Represents a file
FileInfoWrapper
FileLock
Type of lock when requesting a lock on a file.
FileMode
The modes in which a File can be opened.
FilePatternMatch
Represents a file that was matched by searching using a globbing pattern
FileProvider
A read-only file provider abstraction.
FileStat
The result of calling the POSIX stat() function on a file system object.
FileSystem
A generic representation of a file system.
FileSystemEntity
The common super class for io.File, io.Directory, and io.Link objects.
FileSystemEntityType
The type of an entity on the file system, such as a file, directory, or link.
FileSystemEvent
Base event class emitted by FileSystemEntity.watch.
FileSystemInfoBase
Shared abstraction for files and directories
FormattedConsoleLogger
A logger that writes formatted messages to the console output.
FormattedConsoleLoggerProvider
Provider for FormattedConsoleLogger instances.
ForwardingFileSystem
A file system that forwards all methods and properties to a delegate.
ForwardingFileSystemEntity<T extends FileSystemEntity, D extends FileSystemEntity>
A file system entity that forwards all methods and properties to a delegate.
Glob
A glob for matching and listing files and directories.
Host
A program abstraction.
HostApplicationBuilder
Represents a hosted applications and services builder which helps manage configuration, logging, lifetime, and more.
HostApplicationBuilderSettings
Settings for constructing an HostApplicationBuilder.
HostApplicationLifetime
Allows consumers to be notified of application lifetime events. This interface is not intended to be user-replaceable.
HostBuilder
A program initialization abstraction.
HostBuilderAdapter
HostBuilderContext
Context containing the common services on the Host. Some properties may be null until set by the Host.
HostDefaults
Constants for HostBuilder configuration keys.
HostedService
Defines methods for objects that are managed by the host.
HostEnvironment
Provides information about the hosting environment an application is running in.
HostingEnvironment
HostLifetime
Tracks host lifetime.
HttpClientAsyncLogger
An abstraction for asyncronous custom HTTP request logging for a named HttpClient instances returned by HttpClientFactory.
HttpClientBuilder
Fluent builder used to configure named HTTP clients.
HttpClientFactory
A factory abstraction for a component that can create http.BaseClient instances with custom configuration for a given logical name.
HttpClientFactoryOptions
Options used by the default HTTP client factory.
HttpClientLogger
An abstraction for custom HTTP request logging for a named HttpClient instances returned by HttpClientFactory.
HttpClientLoggerHandler
HttpMessageHandler
HttpMessageHandlerBuilder
HttpMessageHandlerBuilderFilter
Used by the DefaultHttpClientFactory to apply additional configuration to the HttpMessageHandlerBuilder immediately before calling build.
HttpMessageHandlerFactory
IConfiguration
Represents a set of key/value application configuration properties.
IConfigurationSection
Represents a section of application configuration values.
ILoggerProviderConfiguration<T>
Provides configuration for a specific logger provider type.
ILoggerProviderConfigurationFactory
Factory to provide configuration for logger providers.
IniConfigurationParser
Parses INI configuration data into key-value pairs.
IniConfigurationProvider
An INI based ConfigurationProvider.
IniConfigurationSource
Represents an INI configuration string as a ConfigurationSource.
IniStreamConfigurationProvider
INI configuration provider that reads from a stream.
IniStreamConfigurationSource
Represents an INI stream as a ConfigurationSource.
InMemoryDirectoryInfo
Represents an in-memory directory for pattern matching without accessing the file system.
InMemoryFileInfo
Represents an in-memory file for pattern matching.
InstrumentRule
Contains a set of parameters used to determine which instruments are enabled for which listeners. Unspecified parameters match anything.
IOSink
A combined byte and text output.
JsonConfigurationParser
JsonConfigurationProvider
A JSON based ConfigurationProvider.
JsonConfigurationSource
JsonConsoleFormatter
A console formatter that formats log messages as JSON.
JsonConsoleFormatterOptions
Options for the built-in JSON console log formatter.
LifetimeTrackingHttpMessageHandler
A delegating handler that tracks the lifetime of HTTP message handlers and prevents premature disposal.
A reference to a symbolic link on the file system.
LinkedNCancellationTokenSource
ListenerSubscription
LogDefineOptions
Options for configuring logger message delegates.
LogEntry<TState>
Holds information about a log entry.
Logger
Represents a type used to perform logging.
LoggerFactory
Represents a type used to configure the logging system and create instances of Logger from the registered LoggerProviders.
LoggerFactoryOptions
The options for a LoggerFactory.
LoggerFilterOptions
The options for a LoggerFilter.
LoggerFilterRule
Defines a rule used to filter log messages.
LoggerMessage
Creates delegates for logging that can be cached and reused for improved performance.
LoggerProvider
Represents a type that can create instances of Logger.
LoggerProviderConfigurationFactoryImpl
Factory implementation for providing configuration to logger providers.
LoggerProviderConfigurationImpl<T>
Implementation of ILoggerProviderConfiguration that retrieves configuration for a specific logger provider type.
LoggingBuilder
An interface for configuring logging providers.
LoggingConfiguration
Loads logging configuration from Configuration.
LoggingHttpMessageHandler
Handles logging of the lifecycle for an HTTP request.
LoggingHttpMessageHandlerBuilderFilter
A filter that adds a LoggingHttpMessageHandler to the HTTP client pipeline for all named clients.
LoggingScopeHttpMessageHandler
A delegating handler that establishes a logging scope for each HTTP request.
Matcher
Searches the file system for files with names that match specified patterns.
MeasurementHandlers
A set of supported measurement types. If a listener does not support a given type, the measurement will be skipped.
MemoryCache
Represents a local in-memory cache whose values are not serialized.
MemoryCacheEntryOptions
Provides options for configuring memory cache entries.
MemoryCacheImpl
Implementation of MemoryCache.
MemoryCacheOptions
Provides configuration options for MemoryCacheImpl.
MemoryCacheStatistics
Holds statistics for the memory cache.
MemoryConfigurationProvider
In-memory implementation of ConfigurationProvider
MemoryConfigurationSource
Represents in-memory data as an ConfigurationSource.
MemoryDistributedCache
An implementation of DistributedCache using an in-memory cache.
MetricsBuilder
Represents a type used to configure the metrics system by registering MetricsListeners and using rules to determine which metrics are enabled.
MetricsListener
Represents a type used to listen to metrics emitted from the system.
MetricsSubscriptionManager
NotFoundDirectoryContents
Represents a non-existing directory
NotFoundFileInfo
Represents a non-existing file.
NullChangeToken
An empty change token that doesn't raise any change callbacks.
NullFileProvider
An empty file provider with no contents.
NullLogger
Minimalistic logger that does nothing.
NullLoggerFactory
An LoggerFactory used to create instance of NullLogger that logs nothing.
NullScope
An empty scope without any logic.
NullTypedLogger<T>
Generic null logger that does nothing.
ObservableInstrumentsSource
An interface registered with each MetricsListener using MetricsListener.initialize(ObservableInstrumentsSource). The listener can call recordObservableInstruments to receive the current set of measurements for enabled observable instruments.
Options<TOptions>
Used to retrieve configured TOptions instances.
OptionsChangeTokenSource<TOptions>
Used to fetch ChangeToken used for tracking options changes.
OptionsFactory<TOptions>
Used to create TOptions instances.
OptionsMonitor<TOptions>
Used for notifications when TOptions instances change.
OptionsMonitorCache<TOptions>
Used by OptionsMonitor to cache TOptions instances.
OptionsSnapshot<TOptions>
Used to access the value of TOptions for the lifetime of a request.
PatternMatchingResult
Represents a collection of FilePatternMatch
PhysicalDirectoryContents
Represents the contents of a physical file directory
PhysicalDirectoryInfo
Represents a directory on a physical filesystem
PhysicalFileInfo
Represents a file on a physical filesystem
PhysicalFileProvider
Looks up files using the on-disk file system.
PhysicalFileProviderOptions
Options for a PhysicalFileProvider.
PhysicalFilesWatcher
A file watcher that watches a physical filesystem for changes.
PollingFileChangeToken
A change token that polls for file changes.
PollingWildcardChangeToken
A change token that polls for file changes matching a wildcard pattern.
PostConfigureOptions<TOptions>
Represents something that configures the TOptions type.
PostEvictionCallbackRegistration
Registration for a callback that should be called when a cache entry is evicted.
ProviderAliasUtilities
Utilities for working with logger provider aliases.
RandomAccessFile
Random access to the data in a file.
Registrations
Set of all the registrations in the token source.
Scope
ServiceCollection
Specifies the contract for a collection of service descriptors.
ServiceDescriptor
Describes a service with its service type, implementation, and lifetime.
ServiceFactoryAdapter
ServiceProvider
Defines a mechanism for retrieving a service object; that is, an object that provides custom support to other objects.
ServiceProviderFactory<TContainerBuilder>
Provides an extension point for creating a container specific builder and a ServiceProvider.
ServiceProviderIsKeyedService
Optional service used to determine if the specified type with the specified service key is available from the ServiceProvider.
ServiceProviderIsService
Optional service used to determine if the specified type is available from the ServiceProvider.
ServiceProviderOptions
Options for configuring various behaviors of the default ServiceProvider implementation.
ServiceScope
The dispose() method ends the scope lifetime. Once dispose is called, any scoped services that have been resolved from ServiceProvider will be disposed.
ServiceScopeFactory
A factory for creating instances of ServiceScope, which is used to create services within a scope.
SimpleConsoleFormatter
A simple console formatter that formats log messages with timestamps, log levels, categories, and exception details.
SimpleConsoleFormatterOptions
Options for the built-in simple console log formatter.
StaticFilterOptionsMonitor
StreamConfigurationProvider
Stream based configuration provider
StreamConfigurationSource
Stream based ConfigurationSource.
SupportRequiredService
Optional contract used by ServiceProviderServiceExtensions.getRequiredService() to resolve services if supported by ServiceProvider.
SystemdConsoleFormatter
A console formatter that formats log messages for systemd journal.
SystemdConsoleFormatterOptions
Options for the built-in systemd console log formatter.
Test
TypedLogger<T>
A generic logger interface used to enable activation of a named logger from dependency injection.
TypedLoggerImpl<T>
Implementation of TypedLogger that wraps an underlying logger instance.
ValidateOptions<TOptions>
Interface used to validate options.
ValidateOptions0<TOptions>
Implementation of ValidateOptions<TOptions>
ValidateOptions1<TOptions, TDep>
ValidateOptions2<TOptions, TDep1, TDep2>
ValidateOptions3<TOptions, TDep1, TDep2, TDep3>
ValidateOptions4<TOptions, TDep1, TDep2, TDep3, TDep4>
ValidateOptions5<TOptions, TDep1, TDep2, TDep3, TDep4, TDep5>
ValidateOptionsResult
Represents the result of an options validation.
ValidationResult
XFile
A CrossFile is a cross-platform, simplified File abstraction.
XFileInfo
Represents a file using cross_file's XFile for cross-platform support.
XmlConfigurationParser
Parses XML configuration data into key-value pairs.
XmlConfigurationProvider
An XML based ConfigurationProvider.
XmlConfigurationSource
Represents an XML configuration string as a ConfigurationSource.
XmlStreamConfigurationProvider
XML configuration provider that reads from a stream.
XmlStreamConfigurationSource
Represents an XML stream as a ConfigurationSource.

Enums

CacheItemPriority
Specifies how items are prioritized for preservation during a memory pressure triggered cleanup.
EvictionReason
Specifies the reason why a cache entry was evicted.
ExclusionFilters
Specifies filtering behavior for files or directories.
LoggerColorBehavior
Describes when to use color when logging messages.
LogLevel
MeterScope
This is used by InstrumentRule to distinguish between meters created via Meter constructors (global) and those created via Dependency Injection with IMeterFactory.Create(MeterOptions) (local).
ServiceLifetime
Specifies the lifetime of a service in a ServiceCollection.

Mixins

ConfigurationProviderMixin
Provides configuration key/values for an application.
EnumFlags
ForwardingDirectory<T extends Directory>
A directory that forwards all methods and properties to a delegate.
ForwardingFile
A file that forwards all methods and properties to a delegate.
A link that forwards all methods and properties to a delegate.
ForwardingRandomAccessFile
A RandomAccessFile implementation that forwards all methods and properties to a delegate.

Extensions

CacheEntryCommit on CacheEntry
Extension to finalize cache entries after they're configured.
ChainedBuilderExtensions on ConfigurationBuilder
Extension methods for adding Configuration to a ConfigurationBuilder.
CommandLineConfigurationExtensions on ConfigurationBuilder
Extension methods for registering CommandLineConfigurationProvider with ConfigurationBuilder.
ConfigurationExtensions on Configuration
Extension methods for configuration classes.
ConfigurationRootExtensions on ConfigurationRoot
Extension methods for ConfigurationRoot.
ConfigurationSectionExtensions on ConfigurationSection
Extension methods for configuration section classes.
ConsoleLoggerFactoryExtensions on LoggingBuilder
Extension methods for the LoggerFactory class.
DebugLoggerFactoryExtensions on LoggingBuilder
Extension methods for the LoggerFactory class.
DistributedCacheExtensions on DistributedCache
Extension methods for DistributedCache.
EnumFlagsExtension on int
EnvironmentVariablesExtensions on ConfigurationBuilder
FilterLoggingBuilderExtensions on LoggingBuilder
Extension methods for setting up logging services in an ServiceCollection.
HostEnvironmentEnvExtensions on HostEnvironment
Extension methods for HostEnvironment.
HostingAbstractionsHostBuilderExtensions on HostBuilder
Provides extension methods for the HostBuilder from the hosting abstractions package.
HostingAbstractionsHostExtensions on Host
HostingHostBuilderExtensions on HostBuilder
Provides extension methods for the HostBuilder from the hosting package.
HttpClientFactoryServiceCollectionExtensions on ServiceCollection
ServiceCollection extensions for configuring HTTP clients.
IniConfigurationExtensions on ConfigurationBuilder
Extension methods for adding INI configuration sources.
InternalConfigurationRootExtensions on ConfigurationRoot
Extensions method for ConfigurationRoot.
JsonConfigurationExtensions on ConfigurationBuilder
Extension methods for adding JsonConfigurationProvider.
LoggerExtensions on Logger
LoggerFactoryExtensions on LoggerFactory
LoggerFactory extension methods for common scenarios.
LoggerFilterOptionsExtensions on LoggerFilterOptions
LoggingBuilderConfigurationExtensions on LoggingBuilder
Extension methods for configuring logging from IConfiguration.
LoggingBuilderExtensions on LoggingBuilder
Extension methods for setting up logging services in a LoggingBuilder.
LoggingServiceCollectionExtensions on ServiceCollection
Extension methods for setting up logging services in a ServiceCollection.
LogLevelExtensions on LogLevel
MatcherExtensions on Matcher
Extension methods for Matcher to simplify common operations.
MemoryCacheExtensions on MemoryCache
Extension methods for MemoryCache.
MemoryConfigurationBuilderExtensions on ConfigurationBuilder
ConfigurationBuilder extension methods for the MemoryConfigurationProvider.
OptionsBuilderExtensions on OptionsBuilder<TOptions>
OptionsServiceCollectionExtensions on ServiceCollection
Extension methods for adding options services to the DI container.
ServiceCollectionContainerBuilderExtensions on ServiceCollection
Extension methods for building a ServiceProvider from a ServiceCollection.
ServiceCollectionDescriptorExtensions on ServiceCollection
Extension methods for adding and removing services to an ServiceCollection.
ServiceCollectionHostedServiceExtensions on ServiceCollection
Extension methods for adding hosted services to a ServiceCollection.
ServiceCollectionServiceExtensions on ServiceCollection
Extension methods for adding services to a ServiceCollection.
ServiceProviderKeyedServiceExtensions on ServiceProvider
Extension methods for getting services from a ServiceProvider.
ServiceProviderServiceExtensions on ServiceProvider
Extension methods for getting services from a ServiceProvider.
ServiceScopeFactoryExtensions on ServiceScopeFactory
Extension methods for getting services from a ServiceScopeFactory.
TypedLoggerFactoryExtensions on LoggerFactory
Extension methods for creating typed loggers.
XmlConfigurationExtensions on ConfigurationBuilder
Extension methods for adding XML configuration sources.

Functions

configurationKeyComparator(String? x, String? y) int
createApplicationBuilder({HostApplicationBuilderSettings? settings}) HostApplicationBuilder
createDefaultBuilder([List<String>? args]) HostBuilder
Initializes a new instance of the HostBuilder class with pre-configured defaults.
equals(String value1, String value2, {bool ignoreCase = true}) bool
isNullOrEmpty(String? value) bool
isNullOrWhitespace(String? value) bool

Typedefs

CallbackRegistration = void Function(Object? state)
CancellationCallback = void Function(Object? state)
CategoryLevelFilterAction = bool Function(String? category, LogLevel level)
ChangeCallback = void Function(Object? state)
Callback signature for change notifications.
ChangeTokenConsumer = void Function()
Action called when the token changes.
ChangeTokenProducer = ChangeToken? Function()
Produces the change token.
ChangeTokenTypedConsumer<TState> = void Function(TState? state)
Action called when the token changes with state.
Configuration = IConfiguration
Alias for IConfiguration for backwards compatibility.
ConfigureAppConfigurationDelegate = void Function(HostBuilderContext context, ConfigurationBuilder configuration)
ConfigureContainer<TContainerBuilder> = void Function(TContainerBuilder containerBuilder)
ConfigureContainerBuilder<TContainerBuilder> = void Function(TContainerBuilder containerBuilder)
ConfigureContainerDelegate<TContainerBuilder> = TContainerBuilder Function(HostBuilderContext context, TContainerBuilder builder)
ConfigureDefaultServiceProvider = void Function(HostBuilderContext context, ServiceProviderOptions options)
ConfigureFilter = bool Function(String name, String category, LogLevel level)
ConfigureHostConfigurationDelegate = void Function(ConfigurationBuilder configuration)
ConfigureLoggerFactoryOptions = void Function(LoggerFactoryOptions options)
ConfigureLoggingBuilder = void Function(LoggingBuilder builder)
ConfigureOptionsAction1 = void Function(LoggerFilterOptions options)
ConfigureServicesDelegate = void Function(HostBuilderContext context, ServiceCollection services)
ContextResolver = HostBuilderContext? Function()
CreateServiceProvider = ServiceProvider Function()
FactoryResolver<TContainerBuilder> = ServiceProviderFactory<TContainerBuilder> Function(HostBuilderContext hostContext)
FilterAction = bool Function(String provider, String category, LogLevel level)
HttpClientAction = void Function(BaseClient client, ServiceProvider services)
HttpMessageHandlerBuilderAction = void Function(HttpMessageHandlerBuilder builder, ServiceProvider services)
ImplementationFactory = Object Function(ServiceProvider services)
A factory to create new instances of the service implementation.
KeyedImplementationFactory = Object Function(ServiceProvider services, Object? serviceKey)
LevelFilterAction = bool Function(LogLevel level)
LogFormatter<TState> = String Function(TState state, Object? error)
Function to create a String message of the state and exception.
LoggerProviderConfiguration<T> = ILoggerProviderConfiguration<T>
LoggerProviderConfigurationFactory = ILoggerProviderConfigurationFactory
MeasurementCallback<TValue> = void Function(Instrument instrument, TValue measurement, Map<String, Object?> tags, Object? state)
A callback to represent the MeterListener callbacks used in measurements recording operation.
PostEvictionDelegate = void Function(Object key, Object? value, EvictionReason reason, Object? state)
Signature for callbacks that are called when a cache entry is evicted.
ServiceProviderFactoryDelegate<TContainerBuilder> = ServiceProviderFactory<TContainerBuilder> Function(HostBuilderContext? context)
Task = Future<void>
TimerCallback = void Function(Object? state)
TypedImplementationFactory<T> = T Function(ServiceProvider services)
TypedKeyedImplementationFactory<T> = T Function(ServiceProvider services, Object? serviceKey)
ValidationCallback0<TOptions> = bool Function(TOptions options)
ValidationCallback1<TOptions, TDep> = bool Function(TOptions options, TDep dependency)
ValidationCallback2<TOptions, TDep1, TDep2> = bool Function(TOptions options, TDep1 dependency1, TDep2 dependency2)
ValidationCallback3<TOptions, TDep1, TDep2, TDep3> = bool Function(TOptions options, TDep1 dependency1, TDep2 dependency2, TDep3 dependency3)
ValidationCallback4<TOptions, TDep1, TDep2, TDep3, TDep4> = bool Function(TOptions options, TDep1 dependency1, TDep2 dependency2, TDep3 dependency3, TDep4 dependency4)
ValidationCallback5<TOptions, TDep1, TDep2, TDep3, TDep4, TDep5> = bool Function(TOptions options, TDep1 dependency1, TDep2 dependency2, TDep3 dependency3, TDep4 dependency4, TDep5 dependency5)
VoidCallback = void Function()

Exceptions / Errors

AggregateException
Represents one or more errors that occur during application execution.
ArgumentException
The exception that is thrown when one of the arguments provided to a method is not valid.
ArgumentNullException
An exception that is thrown when a method is invoked and at least one of the passed arguments is null but should never be null.
FileNotFoundException
FileSystemException
Exception thrown when a file operation fails.
IOException
Base class for all IO related exceptions.
ObjectDisposedException
/// The exception that is thrown when accessing an object that was disposed.
OperationCanceledException
The exception that is thrown in a thread upon cancellation of an operation that the thread was executing.
OSError
An Exception holding information about an error from the operating system.
SystemException
This class is provided as a means to differentiate between system exceptions and application exceptions.