ChatResponseUpdatesStreamExtensions extension
Provides extension methods for combining a stream of ChatResponseUpdate instances into a ChatResponse.
Methods
-
toChatResponse(
) → Future< ChatResponse> -
Available on Stream<
Drains the stream and combines the updates into a single ChatResponse.ChatResponseUpdate> , provided by the ChatResponseUpdatesStreamExtensions extension