ErrorRealtimeServerMessage class
A server message indicating that an error occurred.
This is an experimental feature.
- Inheritance
-
- Object
- RealtimeServerMessage
- ErrorRealtimeServerMessage
- Annotations
-
- @Source(name: 'ErrorRealtimeServerMessage.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Realtime/', commit: '2e537166e4231e50cceb66832b9dfd1382e24d1b')
Constructors
- ErrorRealtimeServerMessage()
- Creates a new ErrorRealtimeServerMessage.
Properties
- error ↔ ErrorContent?
-
The error content.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId ↔ String?
-
The optional message ID associated with the response.
getter/setter pairinherited
- originatingMessageId ↔ String?
-
The ID of the message that originated the error.
getter/setter pair
- rawRepresentation ↔ Object?
-
The raw representation of the response.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ RealtimeServerMessageType
-
The type of the real-time response.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited