reloadOnChange property
Gets or sets a value that indicates whether the source will be loaded if the underlying file changes.
Implementation
bool reloadOnChange = false;
Gets or sets a value that indicates whether the source will be loaded if the underlying file changes.
bool reloadOnChange = false;