FileSystemException class
An exception thrown when a file-based configuration source cannot be read.
This is a web-safe stand-in for dart:io's FileSystemException so that
file-based configuration can be used on platforms without dart:io.
- Implemented types
Constructors
- FileSystemException(String message, [String? path])
-
Creates a FileSystemException with a
messageand optionalpath.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited