FilterClause class abstract
Base class for filter clauses used when querying a vector store.
Deprecated — use VectorStoreFilter and its sealed subclasses instead.
- Implementers
- Annotations
-
- @Deprecated('Use VectorStoreFilter instead.')
- @Source(name: 'FilterClause.cs', namespace: 'Microsoft.Extensions.VectorData', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.VectorData.Abstractions/VectorData/FilterClauses/')
Constructors
- FilterClause()
-
Creates a FilterClause.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited