JsonFileConfigurationSource class
Represents a JSON file as a ConfigurationSource.
- Inheritance
-
- Object
- FileConfigurationSource
- JsonFileConfigurationSource
Constructors
Properties
- fileProvider ↔ FileProvider?
-
Gets or sets the provider used to access the contents of the file.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- onLoadException ↔ void Function(FileLoadExceptionContext context)?
-
Gets or sets the action that's called if an uncaught exception occurs
in FileConfigurationProvider.load.
getter/setter pairinherited
- optional ↔ bool
-
Gets or sets a value that indicates whether loading the file is optional.
getter/setter pairinherited
- path ↔ String?
-
Gets or sets the path to the file.
getter/setter pairinherited
- reloadDelay ↔ int
-
Gets or sets the number of milliseconds that reload will wait before
calling Load.
getter/setter pairinherited
- reloadOnChange ↔ bool
-
Gets or sets a value that indicates whether the source will be loaded
if the underlying file changes.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
ConfigurationBuilder builder) → ConfigurationProvider -
Builds the ConfigurationProvider for this source.
override
-
ensureDefaults(
ConfigurationBuilder builder) → void -
Called to use any default settings on the builder like the FileProvider
or FileLoadExceptionHandler.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveFileProvider(
) → void -
Creates a physical file provider for the nearest existing directory
if no file provider has been set, for absolute Path.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited