Provides hybrid vector-and-keyword search over a collection of records.
Hybrid search combines vector similarity with traditional keyword matching to improve recall for queries that have both semantic and lexical characteristics.
- Annotations
-
- @Source(name: 'IKeywordHybridSearchable.cs', namespace: 'Microsoft.Extensions.VectorData', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.VectorData.Abstractions/VectorData/')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getService<
T> ({Object? key}) → T? - Gets a service of the specified type provided by the underlying store.
-
hybridSearchAsync<
TInput> (TInput value, List< String> keywords, {int top = 3, HybridSearchOptions<TRecord> ? options, CancellationToken? cancellationToken}) → Stream<VectorSearchResult< TRecord> > -
Searches for records that are similar to
valueand matchkeywords. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited