LoggingRealtimeClientSession class
A RealtimeClientSession that logs operations to a Logger.
This is an experimental feature.
- Implemented types
Constructors
- LoggingRealtimeClientSession(RealtimeClientSession _innerSession, {required Logger logger})
-
Creates a new LoggingRealtimeClientSession wrapping
innerSession.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- jsonEncoder ↔ JsonEncoder
-
The JsonEncoder used to serialize log data.
getter/setter pair
- options → RealtimeSessionOptions?
-
The current session options.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disposeAsync(
) → Future< void> -
Performs application-defined tasks associated with freeing, releasing,
or resetting unmanaged resources asynchronously.
override
-
getService<
T> ({Object? key}) → T? -
Asks the session for an object of the specified type
T.override -
getStreamingResponse(
{CancellationToken? cancellationToken}) → Stream< RealtimeServerMessage> -
Streams the response messages generated by the session.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
RealtimeClientMessage message, {CancellationToken? cancellationToken}) → Future< void> -
Sends a client
messageto the session.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited