OpenAIClientOptions class
Configuration options for an OpenAI-compatible API client.
Pass an instance to any OpenAI* client constructor to customise the
endpoint (e.g. to point at an LM Studio local server) or to inject an
http.Client for testing.
Constructors
- OpenAIClientOptions({Uri? endpoint, Client? httpClient})
- Creates a new OpenAIClientOptions.
Properties
- endpoint → Uri
-
The base URI of the OpenAI-compatible API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpClient → Client?
-
An optional HTTP client to use for requests.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited