RealtimeClient class abstract
Represents a real-time client.
Provides methods to create and manage real-time sessions.
This is an experimental feature.
- Implemented types
- Implementers
- Available extensions
- Annotations
-
- @Source(name: 'IRealtimeClient.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Realtime/', commit: '2e537166e4231e50cceb66832b9dfd1382e24d1b')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asBuilder(
) → RealtimeClientBuilder -
Available on RealtimeClient, provided by the RealtimeClientBuilderRealtimeClientExtensions extension
Creates a new RealtimeClientBuilder using this client as the innermost client in the pipeline. -
createSession(
{RealtimeSessionOptions? options, CancellationToken? cancellationToken}) → Future< RealtimeClientSession> -
Creates a new real-time session with the specified
options. -
dispose(
) → void -
Performs application-defined tasks associated with freeing, releasing,
or resetting unmanaged resources.
inherited
-
getService<
T> ({Object? key}) → T? -
Asks the client for an object of the specified type
T. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited