RealtimeClientSession class abstract
Represents a real-time session.
Provides methods to manage a real-time session and to interact with the real-time model.
This is an experimental feature.
- Implemented types
- Implementers
- Annotations
-
- @Source(name: 'IRealtimeClientSession.cs', namespace: 'Microsoft.Extensions.AI', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.AI.Abstractions/Realtime/', commit: '2e537166e4231e50cceb66832b9dfd1382e24d1b')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → RealtimeSessionOptions?
-
The current session options.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disposeAsync(
) → Future< void> -
Performs application-defined tasks associated with freeing, releasing,
or resetting unmanaged resources asynchronously.
inherited
-
getService<
T> ({Object? key}) → T? -
Asks the session for an object of the specified type
T. -
getStreamingResponse(
{CancellationToken? cancellationToken}) → Stream< RealtimeServerMessage> - Streams the response messages generated by the session.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
RealtimeClientMessage message, {CancellationToken? cancellationToken}) → Future< void> -
Sends a client
messageto the session. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited