RecordRetrievalOptions class
Options for retrieving records from a vector store collection by key.
- Annotations
-
- @Source(name: 'RecordRetrievalOptions.cs', namespace: 'Microsoft.Extensions.VectorData', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.VectorData.Abstractions/VectorData/')
Constructors
- RecordRetrievalOptions({bool includeVectors = false})
- Creates a RecordRetrievalOptions.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeVectors ↔ bool
-
Whether to include vector fields in the retrieved records.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited