TranscriptionOptions class
Represents the options for a speech-to-text transcription session.
This is an experimental feature.
Constructors
- TranscriptionOptions({String? speechLanguage, String? modelId, String? prompt})
- Creates a new TranscriptionOptions.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- modelId ↔ String?
-
The model to use for transcription.
getter/setter pair
- prompt ↔ String?
-
An optional prompt to guide the transcription.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speechLanguage ↔ String?
-
The language of the input speech.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited