Provides vector similarity search over a collection of records.
Implemented by VectorStoreCollection and by any type that supports similarity search without the full collection management surface.
- Implementers
- Annotations
-
- @Source(name: 'IVectorSearchable.cs', namespace: 'Microsoft.Extensions.VectorData', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.VectorData.Abstractions/VectorData/')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getService<
T> ({Object? key}) → T? - Gets a service of the specified type provided by the underlying store.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
searchAsync<
TInput> (TInput value, {int top = 3, VectorSearchOptions< TRecord> ? options, CancellationToken? cancellationToken}) → Stream<VectorSearchResult< TRecord> > -
Searches for records that are similar to
value. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited