VectorStoreCollectionOptions class
Base options for configuring a VectorStoreCollection.
Subclass this to add provider-specific options.
- Annotations
-
- @Source(name: 'VectorStoreCollectionOptions.cs', namespace: 'Microsoft.Extensions.VectorData', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.VectorData.Abstractions/VectorData/')
Constructors
- VectorStoreCollectionOptions({VectorStoreCollectionDefinition? definition, EmbeddingGenerator? embeddingGenerator})
- Creates a VectorStoreCollectionOptions.
Properties
- definition ↔ VectorStoreCollectionDefinition?
-
The explicit schema definition for the collection.
getter/setter pair
- embeddingGenerator ↔ EmbeddingGenerator?
-
The embedding generator used to automatically produce vector embeddings.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited