VectorStoreProperty class abstract
Base class for all vector store record property definitions.
- Implementers
- Annotations
-
- @Source(name: 'VectorStoreProperty.cs', namespace: 'Microsoft.Extensions.VectorData', repository: 'dotnet/extensions', path: 'src/Libraries/Microsoft.Extensions.VectorData.Abstractions/VectorData/RecordDefinition/')
Constructors
- VectorStoreProperty(String propertyName)
-
Creates a new VectorStoreProperty with the given
propertyName.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- propertyName → String
-
The name of the property on the record model.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageName ↔ String?
-
The name used when storing this property in the vector store.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited